/* Generated by re2c 0.12.3 */
#line 1 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
#define	YYCTYPE		unsigned char
#define	YYCURSOR	cursor
#define	YYLIMIT		limit
#define	YYMARKER	marker
#define YYFILL(n)	{}
#if 0	// As long as the buffer ends with '\n', we need do nothing special for YYFILL.
	// This buffer must be as large as the largest YYFILL call
	YYCTYPE eofbuf[9];
#define	YYFILL(n)	\
	{ if(!sc_End) { \
	   if(n == 2) { eofbuf[0] = *cursor; } \
	   else if(n >= 3 && n <= 9) { memcpy(eofbuf, cursor, n-1); } \
	   eofbuf[n-1] = '\n'; \
	   cursor = eofbuf; \
	   limit = eofbuf + n - 1; \
	   sc_End = true; } \
	} \
	assert(n <= sizeof eofbuf)	// Semicolon intentionally omitted
#endif

//#define YYDEBUG(s,c) { Printf ("%d: %02x\n", s, c); }
#define YYDEBUG(s,c)

	const char *cursor = ScriptPtr;
	const char *limit = ScriptEndPtr;

std1:
	tok = YYCURSOR;
std2:
#line 51 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"

	if (tokens)	// A well-defined scanner, based on the c.re example.
	{
#define RET(x)	TokenType = x; goto normal_token;
	
#line 39 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
{
	YYCTYPE yych;
	unsigned int yyaccept = 0;

	if((YYLIMIT - YYCURSOR) < 18) YYFILL(18);
	yych = *YYCURSOR;
	switch(yych) {
	case 0x09:
	case 0x0B:
	case 0x0C:
	case 0x0D:
	case ' ':	goto yy78;
	case 0x0A:	goto yy80;
	case '!':	goto yy54;
	case '"':	goto yy32;
	case '#':	goto yy4;
	case '%':	goto yy44;
	case '&':	goto yy46;
	case '\'':	goto yy33;
	case '(':	goto yy68;
	case ')':	goto yy70;
	case '*':	goto yy42;
	case '+':	goto yy38;
	case ',':	goto yy64;
	case '-':	goto yy40;
	case '.':	goto yy30;
	case '/':	goto yy2;
	case '0':	goto yy27;
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':	goto yy29;
	case ':':	goto yy66;
	case ';':	goto yy58;
	case '<':	goto yy36;
	case '=':	goto yy52;
	case '>':	goto yy34;
	case '?':	goto yy76;
	case 'A':
	case 'a':	goto yy22;
	case 'B':
	case 'b':	goto yy6;
	case 'C':
	case 'c':	goto yy8;
	case 'D':
	case 'd':	goto yy9;
	case 'E':
	case 'e':	goto yy10;
	case 'F':
	case 'f':	goto yy11;
	case 'G':
	case 'g':	goto yy12;
	case 'H':
	case 'J':
	case 'K':
	case 'Q':
	case 'X':
	case 'Y':
	case 'Z':
	case '_':
	case 'h':
	case 'j':
	case 'k':
	case 'q':
	case 'x':
	case 'y':
	case 'z':	goto yy26;
	case 'I':
	case 'i':	goto yy13;
	case 'L':
	case 'l':	goto yy19;
	case 'M':
	case 'm':	goto yy20;
	case 'N':
	case 'n':	goto yy21;
	case 'O':
	case 'o':	goto yy24;
	case 'P':
	case 'p':	goto yy25;
	case 'R':
	case 'r':	goto yy14;
	case 'S':
	case 's':	goto yy15;
	case 'T':
	case 't':	goto yy23;
	case 'U':
	case 'u':	goto yy16;
	case 'V':
	case 'v':	goto yy17;
	case 'W':
	case 'w':	goto yy18;
	case '[':	goto yy72;
	case ']':	goto yy74;
	case '^':	goto yy48;
	case '{':	goto yy60;
	case '|':	goto yy50;
	case '}':	goto yy62;
	case '~':	goto yy56;
	default:	goto yy82;
	}
yy2:
	yyaccept = 0;
	yych = *(YYMARKER = ++YYCURSOR);
	if(yych <= '.') {
		if(yych == '*') goto yy678;
	} else {
		if(yych <= '/') goto yy676;
		if(yych == '=') goto yy674;
	}
yy3:
#line 224 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET('/'); }
#line 157 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy4:
	yyaccept = 1;
	yych = *(YYMARKER = ++YYCURSOR);
	if(yych <= 'e') {
		if(yych == 'I') goto yy649;
		if(yych >= 'e') goto yy650;
	} else {
		if(yych <= 'i') {
			if(yych >= 'i') goto yy649;
		} else {
			if(yych == 'r') goto yy651;
		}
	}
yy5:
#line 235 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{
			ScriptError ("Unexpected character: %c (ASCII %d)\n", *tok, *tok);
			goto std1;
		}
#line 177 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy6:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Y') {
		if(yych <= 'Q') {
			if(yych == 'O') goto yy636;
			goto yy183;
		} else {
			if(yych <= 'R') goto yy637;
			if(yych <= 'X') goto yy183;
			goto yy638;
		}
	} else {
		if(yych <= 'q') {
			if(yych == 'o') goto yy636;
			goto yy183;
		} else {
			if(yych <= 'r') goto yy637;
			if(yych == 'y') goto yy638;
			goto yy183;
		}
	}
yy7:
#line 166 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_Identifier); }
#line 202 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy8:
	yych = *++YYCURSOR;
	switch(yych) {
	case 'A':
	case 'a':	goto yy594;
	case 'H':
	case 'h':	goto yy595;
	case 'L':
	case 'l':	goto yy596;
	case 'O':
	case 'o':	goto yy597;
	case 'R':
	case 'r':	goto yy598;
	default:	goto yy183;
	}
yy9:
	yych = *++YYCURSOR;
	if(yych <= 'O') {
		if(yych == 'E') goto yy567;
		if(yych <= 'N') goto yy183;
		goto yy568;
	} else {
		if(yych <= 'e') {
			if(yych <= 'd') goto yy183;
			goto yy567;
		} else {
			if(yych == 'o') goto yy568;
			goto yy183;
		}
	}
yy10:
	yych = *++YYCURSOR;
	if(yych <= 'X') {
		if(yych <= 'N') {
			if(yych == 'L') goto yy539;
			if(yych <= 'M') goto yy183;
			goto yy540;
		} else {
			if(yych == 'V') goto yy541;
			if(yych <= 'W') goto yy183;
			goto yy542;
		}
	} else {
		if(yych <= 'n') {
			if(yych == 'l') goto yy539;
			if(yych <= 'm') goto yy183;
			goto yy540;
		} else {
			if(yych <= 'v') {
				if(yych <= 'u') goto yy183;
				goto yy541;
			} else {
				if(yych == 'x') goto yy542;
				goto yy183;
			}
		}
	}
yy11:
	yych = *++YYCURSOR;
	switch(yych) {
	case 'A':
	case 'a':	goto yy498;
	case 'I':
	case 'i':	goto yy499;
	case 'L':
	case 'l':	goto yy500;
	case 'O':
	case 'o':	goto yy501;
	case 'R':
	case 'r':	goto yy502;
	default:	goto yy183;
	}
yy12:
	yych = *++YYCURSOR;
	if(yych <= 'O') {
		if(yych == 'L') goto yy488;
		if(yych <= 'N') goto yy183;
		goto yy489;
	} else {
		if(yych <= 'l') {
			if(yych <= 'k') goto yy183;
			goto yy488;
		} else {
			if(yych == 'o') goto yy489;
			goto yy183;
		}
	}
yy13:
	yych = *++YYCURSOR;
	if(yych <= 'T') {
		if(yych <= 'M') {
			if(yych <= 'E') goto yy183;
			if(yych <= 'F') goto yy456;
			if(yych <= 'G') goto yy458;
			goto yy183;
		} else {
			if(yych <= 'N') goto yy459;
			if(yych <= 'R') goto yy183;
			if(yych <= 'S') goto yy461;
			goto yy463;
		}
	} else {
		if(yych <= 'm') {
			if(yych <= 'e') goto yy183;
			if(yych <= 'f') goto yy456;
			if(yych <= 'g') goto yy458;
			goto yy183;
		} else {
			if(yych <= 'r') {
				if(yych <= 'n') goto yy459;
				goto yy183;
			} else {
				if(yych <= 's') goto yy461;
				if(yych <= 't') goto yy463;
				goto yy183;
			}
		}
	}
yy14:
	yych = *++YYCURSOR;
	if(yych <= 'E') {
		if(yych == 'A') goto yy428;
		if(yych <= 'D') goto yy183;
		goto yy429;
	} else {
		if(yych <= 'a') {
			if(yych <= '`') goto yy183;
			goto yy428;
		} else {
			if(yych == 'e') goto yy429;
			goto yy183;
		}
	}
yy15:
	yych = *++YYCURSOR;
	switch(yych) {
	case 'B':
	case 'b':	goto yy365;
	case 'E':
	case 'e':	goto yy366;
	case 'H':
	case 'h':	goto yy367;
	case 'I':
	case 'i':	goto yy368;
	case 'O':
	case 'o':	goto yy369;
	case 'T':
	case 't':	goto yy370;
	case 'U':
	case 'u':	goto yy371;
	case 'W':
	case 'w':	goto yy372;
	default:	goto yy183;
	}
yy16:
	yych = *++YYCURSOR;
	switch(yych) {
	case 'I':
	case 'i':	goto yy345;
	case 'L':
	case 'l':	goto yy346;
	case 'N':
	case 'n':	goto yy347;
	case 'S':
	case 's':	goto yy348;
	default:	goto yy183;
	}
yy17:
	yych = *++YYCURSOR;
	if(yych <= 'O') {
		if(yych <= 'E') {
			if(yych == 'A') goto yy318;
			if(yych <= 'D') goto yy183;
			goto yy319;
		} else {
			if(yych == 'I') goto yy320;
			if(yych <= 'N') goto yy183;
			goto yy321;
		}
	} else {
		if(yych <= 'e') {
			if(yych == 'a') goto yy318;
			if(yych <= 'd') goto yy183;
			goto yy319;
		} else {
			if(yych <= 'i') {
				if(yych <= 'h') goto yy183;
				goto yy320;
			} else {
				if(yych == 'o') goto yy321;
				goto yy183;
			}
		}
	}
yy18:
	yych = *++YYCURSOR;
	if(yych == 'H') goto yy313;
	if(yych == 'h') goto yy313;
	goto yy183;
yy19:
	yych = *++YYCURSOR;
	if(yych <= 'O') {
		if(yych == 'A') goto yy295;
		if(yych <= 'N') goto yy183;
		goto yy296;
	} else {
		if(yych <= 'a') {
			if(yych <= '`') goto yy183;
			goto yy295;
		} else {
			if(yych == 'o') goto yy296;
			goto yy183;
		}
	}
yy20:
	yych = *++YYCURSOR;
	if(yych <= 'O') {
		if(yych == 'A') goto yy288;
		if(yych <= 'N') goto yy183;
		goto yy289;
	} else {
		if(yych <= 'a') {
			if(yych <= '`') goto yy183;
			goto yy288;
		} else {
			if(yych == 'o') goto yy289;
			goto yy183;
		}
	}
yy21:
	yych = *++YYCURSOR;
	if(yych <= 'O') {
		if(yych <= 'D') {
			if(yych == 'A') goto yy272;
			goto yy183;
		} else {
			if(yych <= 'E') goto yy273;
			if(yych <= 'N') goto yy183;
			goto yy274;
		}
	} else {
		if(yych <= 'd') {
			if(yych == 'a') goto yy272;
			goto yy183;
		} else {
			if(yych <= 'e') goto yy273;
			if(yych == 'o') goto yy274;
			goto yy183;
		}
	}
yy22:
	yych = *++YYCURSOR;
	switch(yych) {
	case 'B':
	case 'b':	goto yy234;
	case 'C':
	case 'c':	goto yy235;
	case 'L':
	case 'l':	goto yy236;
	case 'N':
	case 'n':	goto yy237;
	case 'R':
	case 'r':	goto yy238;
	case 'U':
	case 'u':	goto yy239;
	default:	goto yy183;
	}
yy23:
	yych = *++YYCURSOR;
	if(yych <= 'R') {
		if(yych == 'H') goto yy216;
		if(yych <= 'Q') goto yy183;
		goto yy217;
	} else {
		if(yych <= 'h') {
			if(yych <= 'g') goto yy183;
			goto yy216;
		} else {
			if(yych == 'r') goto yy217;
			goto yy183;
		}
	}
yy24:
	yych = *++YYCURSOR;
	if(yych <= 'U') {
		if(yych == 'P') goto yy205;
		if(yych <= 'T') goto yy183;
		goto yy206;
	} else {
		if(yych <= 'p') {
			if(yych <= 'o') goto yy183;
			goto yy205;
		} else {
			if(yych == 'u') goto yy206;
			goto yy183;
		}
	}
yy25:
	yych = *++YYCURSOR;
	if(yych <= 'U') {
		if(yych == 'R') goto yy184;
		if(yych <= 'T') goto yy183;
		goto yy185;
	} else {
		if(yych <= 'r') {
			if(yych <= 'q') goto yy183;
			goto yy184;
		} else {
			if(yych == 'u') goto yy185;
			goto yy183;
		}
	}
yy26:
	yych = *++YYCURSOR;
	goto yy183;
yy27:
	yyaccept = 2;
	yych = *(YYMARKER = ++YYCURSOR);
	if(yych == 'X') goto yy179;
	if(yych == 'x') goto yy179;
	goto yy178;
yy28:
#line 169 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_IntConst); }
#line 527 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy29:
	yyaccept = 2;
	yych = *(YYMARKER = ++YYCURSOR);
	goto yy161;
yy30:
	++YYCURSOR;
	if((yych = *YYCURSOR) == '.') goto yy147;
	if(yych <= '/') goto yy31;
	if(yych <= '9') goto yy149;
yy31:
#line 217 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET('.'); }
#line 540 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy32:
	yyaccept = 1;
	yych = *(YYMARKER = ++YYCURSOR);
	goto yy141;
yy33:
	yyaccept = 1;
	yych = *(YYMARKER = ++YYCURSOR);
	if(yych == 0x0A) goto yy5;
	goto yy137;
yy34:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= '<') goto yy35;
	if(yych <= '=') goto yy126;
	if(yych <= '>') goto yy128;
yy35:
#line 227 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET('>'); }
#line 558 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy36:
	yyaccept = 3;
	yych = *(YYMARKER = ++YYCURSOR);
	if(yych <= ';') goto yy37;
	if(yych <= '<') goto yy120;
	if(yych <= '=') goto yy118;
	if(yych <= '>') goto yy117;
yy37:
#line 226 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET('<'); }
#line 569 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy38:
	++YYCURSOR;
	if((yych = *YYCURSOR) == '+') goto yy113;
	if(yych == '=') goto yy115;
#line 222 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET('+'); }
#line 576 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy40:
	++YYCURSOR;
	if((yych = *YYCURSOR) == '-') goto yy109;
	if(yych == '=') goto yy111;
#line 221 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET('-'); }
#line 583 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy42:
	++YYCURSOR;
	if((yych = *YYCURSOR) == '*') goto yy105;
	if(yych == '=') goto yy107;
#line 223 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET('*'); }
#line 590 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy44:
	++YYCURSOR;
	if((yych = *YYCURSOR) == '=') goto yy103;
#line 225 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET('%'); }
#line 596 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy46:
	++YYCURSOR;
	if((yych = *YYCURSOR) == '&') goto yy99;
	if(yych == '=') goto yy101;
#line 218 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET('&'); }
#line 603 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy48:
	++YYCURSOR;
	if((yych = *YYCURSOR) == '=') goto yy97;
#line 228 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET('^'); }
#line 609 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy50:
	++YYCURSOR;
	if((yych = *YYCURSOR) == '=') goto yy95;
	if(yych == '|') goto yy93;
#line 229 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET('|'); }
#line 616 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy52:
	++YYCURSOR;
	if((yych = *YYCURSOR) == '=') goto yy91;
#line 212 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET('='); }
#line 622 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy54:
	++YYCURSOR;
	if((yych = *YYCURSOR) == '=') goto yy89;
#line 219 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET('!'); }
#line 628 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy56:
	yyaccept = 4;
	yych = *(YYMARKER = ++YYCURSOR);
	if(yych == '=') goto yy85;
yy57:
#line 220 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET('~'); }
#line 636 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy58:
	++YYCURSOR;
#line 207 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(';'); }
#line 641 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy60:
	++YYCURSOR;
#line 208 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET('{'); }
#line 646 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy62:
	++YYCURSOR;
#line 209 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET('}'); }
#line 651 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy64:
	++YYCURSOR;
#line 210 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(','); }
#line 656 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy66:
	++YYCURSOR;
#line 211 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(':'); }
#line 661 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy68:
	++YYCURSOR;
#line 213 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET('('); }
#line 666 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy70:
	++YYCURSOR;
#line 214 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(')'); }
#line 671 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy72:
	++YYCURSOR;
#line 215 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET('['); }
#line 676 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy74:
	++YYCURSOR;
#line 216 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(']'); }
#line 681 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy76:
	++YYCURSOR;
#line 230 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET('?'); }
#line 686 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy78:
	++YYCURSOR;
	yych = *YYCURSOR;
	goto yy84;
yy79:
#line 232 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ goto std1; }
#line 694 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy80:
	++YYCURSOR;
#line 233 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ goto newline; }
#line 699 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy82:
	yych = *++YYCURSOR;
	goto yy5;
yy83:
	++YYCURSOR;
	if(YYLIMIT == YYCURSOR) YYFILL(1);
	yych = *YYCURSOR;
yy84:
	if(yych <= 0x0A) {
		if(yych == 0x09) goto yy83;
		goto yy79;
	} else {
		if(yych <= 0x0D) goto yy83;
		if(yych == ' ') goto yy83;
		goto yy79;
	}
yy85:
	yych = *++YYCURSOR;
	if(yych == '=') goto yy87;
yy86:
	YYCURSOR = YYMARKER;
	if(yyaccept <= 3) {
		if(yyaccept <= 1) {
			if(yyaccept <= 0) {
				goto yy3;
			} else {
				goto yy5;
			}
		} else {
			if(yyaccept <= 2) {
				goto yy28;
			} else {
				goto yy37;
			}
		}
	} else {
		if(yyaccept <= 5) {
			if(yyaccept <= 4) {
				goto yy57;
			} else {
				goto yy145;
			}
		} else {
			goto yy151;
		}
	}
yy87:
	++YYCURSOR;
#line 204 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_ApproxEq); }
#line 750 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy89:
	++YYCURSOR;
#line 203 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_Neq); }
#line 755 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy91:
	++YYCURSOR;
#line 202 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_Eq); }
#line 760 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy93:
	++YYCURSOR;
#line 199 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_OrOr); }
#line 765 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy95:
	++YYCURSOR;
#line 192 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_OrEq); }
#line 770 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy97:
	++YYCURSOR;
#line 191 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_XorEq); }
#line 775 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy99:
	++YYCURSOR;
#line 198 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_AndAnd); }
#line 780 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy101:
	++YYCURSOR;
#line 190 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_AndEq); }
#line 785 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy103:
	++YYCURSOR;
#line 189 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_ModEq); }
#line 790 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy105:
	++YYCURSOR;
#line 206 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_MulMul); }
#line 795 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy107:
	++YYCURSOR;
#line 187 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_MulEq); }
#line 800 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy109:
	++YYCURSOR;
#line 197 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_Decr); }
#line 805 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy111:
	++YYCURSOR;
#line 186 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_SubEq); }
#line 810 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy113:
	++YYCURSOR;
#line 196 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_Incr); }
#line 815 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy115:
	++YYCURSOR;
#line 185 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_AddEq); }
#line 820 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy117:
	yych = *++YYCURSOR;
	if(yych == '=') goto yy124;
	goto yy86;
yy118:
	++YYCURSOR;
#line 200 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_Leq); }
#line 829 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy120:
	++YYCURSOR;
	if((yych = *YYCURSOR) == '=') goto yy122;
#line 195 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_LShift); }
#line 835 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy122:
	++YYCURSOR;
#line 184 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_LShiftEq); }
#line 840 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy124:
	++YYCURSOR;
#line 205 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_LtGtEq); }
#line 845 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy126:
	++YYCURSOR;
#line 201 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_Geq); }
#line 850 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy128:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= '<') goto yy129;
	if(yych <= '=') goto yy132;
	if(yych <= '>') goto yy130;
yy129:
#line 194 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_RShift); }
#line 859 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy130:
	++YYCURSOR;
	if((yych = *YYCURSOR) == '=') goto yy134;
#line 193 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_URShift); }
#line 865 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy132:
	++YYCURSOR;
#line 183 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_RShiftEq); }
#line 870 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy134:
	++YYCURSOR;
#line 182 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_URShiftEq); }
#line 875 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy136:
	++YYCURSOR;
	if(YYLIMIT == YYCURSOR) YYFILL(1);
	yych = *YYCURSOR;
yy137:
	if(yych == 0x0A) goto yy86;
	if(yych != '\'') goto yy136;
	++YYCURSOR;
#line 178 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_NameConst); }
#line 886 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy140:
	++YYCURSOR;
	if(YYLIMIT == YYCURSOR) YYFILL(1);
	yych = *YYCURSOR;
yy141:
	if(yych == '"') goto yy144;
	if(yych != '\\') goto yy140;
yy142:
	++YYCURSOR;
	if(YYLIMIT == YYCURSOR) YYFILL(1);
	yych = *YYCURSOR;
	if(yych == '"') goto yy146;
	if(yych == '\\') goto yy142;
	goto yy140;
yy144:
	++YYCURSOR;
yy145:
#line 175 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_StringConst); }
#line 906 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy146:
	yyaccept = 5;
	YYMARKER = ++YYCURSOR;
	if(YYLIMIT == YYCURSOR) YYFILL(1);
	yych = *YYCURSOR;
	if(yych == '"') goto yy144;
	if(yych == '\\') goto yy142;
	goto yy140;
yy147:
	++YYCURSOR;
	if((yych = *YYCURSOR) == '.') goto yy157;
#line 180 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_DotDot); }
#line 920 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy149:
	yyaccept = 6;
	YYMARKER = ++YYCURSOR;
	if((YYLIMIT - YYCURSOR) < 3) YYFILL(3);
	yych = *YYCURSOR;
	if(yych <= 'K') {
		if(yych <= 'D') {
			if(yych <= '/') goto yy151;
			if(yych <= '9') goto yy149;
		} else {
			if(yych <= 'E') goto yy152;
			if(yych <= 'F') goto yy153;
		}
	} else {
		if(yych <= 'e') {
			if(yych <= 'L') goto yy153;
			if(yych >= 'e') goto yy152;
		} else {
			if(yych <= 'f') goto yy153;
			if(yych == 'l') goto yy153;
		}
	}
yy151:
#line 172 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_FloatConst); }
#line 946 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy152:
	yych = *++YYCURSOR;
	if(yych <= ',') {
		if(yych == '+') goto yy154;
		goto yy86;
	} else {
		if(yych <= '-') goto yy154;
		if(yych <= '/') goto yy86;
		if(yych <= '9') goto yy155;
		goto yy86;
	}
yy153:
	yych = *++YYCURSOR;
	goto yy151;
yy154:
	yych = *++YYCURSOR;
	if(yych <= '/') goto yy86;
	if(yych >= ':') goto yy86;
yy155:
	++YYCURSOR;
	if(YYLIMIT == YYCURSOR) YYFILL(1);
	yych = *YYCURSOR;
	if(yych <= 'K') {
		if(yych <= '9') {
			if(yych <= '/') goto yy151;
			goto yy155;
		} else {
			if(yych == 'F') goto yy153;
			goto yy151;
		}
	} else {
		if(yych <= 'f') {
			if(yych <= 'L') goto yy153;
			if(yych <= 'e') goto yy151;
			goto yy153;
		} else {
			if(yych == 'l') goto yy153;
			goto yy151;
		}
	}
yy157:
	++YYCURSOR;
#line 181 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_Ellipsis); }
#line 991 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy159:
	yyaccept = 6;
	yych = *(YYMARKER = ++YYCURSOR);
	if(yych == 'E') goto yy169;
	if(yych == 'e') goto yy169;
	goto yy168;
yy160:
	yyaccept = 2;
	YYMARKER = ++YYCURSOR;
	if((YYLIMIT - YYCURSOR) < 4) YYFILL(4);
	yych = *YYCURSOR;
yy161:
	if(yych <= 'L') {
		if(yych <= '9') {
			if(yych == '.') goto yy159;
			if(yych <= '/') goto yy28;
			goto yy160;
		} else {
			if(yych == 'E') goto yy162;
			if(yych <= 'K') goto yy28;
			goto yy163;
		}
	} else {
		if(yych <= 'e') {
			if(yych == 'U') goto yy163;
			if(yych <= 'd') goto yy28;
		} else {
			if(yych <= 'l') {
				if(yych <= 'k') goto yy28;
				goto yy163;
			} else {
				if(yych == 'u') goto yy163;
				goto yy28;
			}
		}
	}
yy162:
	yych = *++YYCURSOR;
	if(yych <= ',') {
		if(yych == '+') goto yy164;
		goto yy86;
	} else {
		if(yych <= '-') goto yy164;
		if(yych <= '/') goto yy86;
		if(yych <= '9') goto yy165;
		goto yy86;
	}
yy163:
	yych = *++YYCURSOR;
	goto yy28;
yy164:
	yych = *++YYCURSOR;
	if(yych <= '/') goto yy86;
	if(yych >= ':') goto yy86;
yy165:
	++YYCURSOR;
	if(YYLIMIT == YYCURSOR) YYFILL(1);
	yych = *YYCURSOR;
	if(yych <= 'K') {
		if(yych <= '9') {
			if(yych <= '/') goto yy151;
			goto yy165;
		} else {
			if(yych == 'F') goto yy153;
			goto yy151;
		}
	} else {
		if(yych <= 'f') {
			if(yych <= 'L') goto yy153;
			if(yych <= 'e') goto yy151;
			goto yy153;
		} else {
			if(yych == 'l') goto yy153;
			goto yy151;
		}
	}
yy167:
	yyaccept = 6;
	YYMARKER = ++YYCURSOR;
	if((YYLIMIT - YYCURSOR) < 3) YYFILL(3);
	yych = *YYCURSOR;
yy168:
	if(yych <= 'K') {
		if(yych <= 'D') {
			if(yych <= '/') goto yy151;
			if(yych <= '9') goto yy167;
			goto yy151;
		} else {
			if(yych <= 'E') goto yy173;
			if(yych <= 'F') goto yy153;
			goto yy151;
		}
	} else {
		if(yych <= 'e') {
			if(yych <= 'L') goto yy153;
			if(yych <= 'd') goto yy151;
			goto yy173;
		} else {
			if(yych <= 'f') goto yy153;
			if(yych == 'l') goto yy153;
			goto yy151;
		}
	}
yy169:
	yych = *++YYCURSOR;
	if(yych <= ',') {
		if(yych != '+') goto yy86;
	} else {
		if(yych <= '-') goto yy170;
		if(yych <= '/') goto yy86;
		if(yych <= '9') goto yy171;
		goto yy86;
	}
yy170:
	yych = *++YYCURSOR;
	if(yych <= '/') goto yy86;
	if(yych >= ':') goto yy86;
yy171:
	++YYCURSOR;
	if(YYLIMIT == YYCURSOR) YYFILL(1);
	yych = *YYCURSOR;
	if(yych <= 'K') {
		if(yych <= '9') {
			if(yych <= '/') goto yy151;
			goto yy171;
		} else {
			if(yych == 'F') goto yy153;
			goto yy151;
		}
	} else {
		if(yych <= 'f') {
			if(yych <= 'L') goto yy153;
			if(yych <= 'e') goto yy151;
			goto yy153;
		} else {
			if(yych == 'l') goto yy153;
			goto yy151;
		}
	}
yy173:
	yych = *++YYCURSOR;
	if(yych <= ',') {
		if(yych != '+') goto yy86;
	} else {
		if(yych <= '-') goto yy174;
		if(yych <= '/') goto yy86;
		if(yych <= '9') goto yy175;
		goto yy86;
	}
yy174:
	yych = *++YYCURSOR;
	if(yych <= '/') goto yy86;
	if(yych >= ':') goto yy86;
yy175:
	++YYCURSOR;
	if(YYLIMIT == YYCURSOR) YYFILL(1);
	yych = *YYCURSOR;
	if(yych <= 'K') {
		if(yych <= '9') {
			if(yych <= '/') goto yy151;
			goto yy175;
		} else {
			if(yych == 'F') goto yy153;
			goto yy151;
		}
	} else {
		if(yych <= 'f') {
			if(yych <= 'L') goto yy153;
			if(yych <= 'e') goto yy151;
			goto yy153;
		} else {
			if(yych == 'l') goto yy153;
			goto yy151;
		}
	}
yy177:
	yyaccept = 2;
	YYMARKER = ++YYCURSOR;
	if((YYLIMIT - YYCURSOR) < 4) YYFILL(4);
	yych = *YYCURSOR;
yy178:
	if(yych <= 'L') {
		if(yych <= '9') {
			if(yych == '.') goto yy159;
			if(yych <= '/') goto yy28;
			goto yy177;
		} else {
			if(yych == 'E') goto yy162;
			if(yych <= 'K') goto yy28;
			goto yy163;
		}
	} else {
		if(yych <= 'e') {
			if(yych == 'U') goto yy163;
			if(yych <= 'd') goto yy28;
			goto yy162;
		} else {
			if(yych <= 'l') {
				if(yych <= 'k') goto yy28;
				goto yy163;
			} else {
				if(yych == 'u') goto yy163;
				goto yy28;
			}
		}
	}
yy179:
	yych = *++YYCURSOR;
	if(yych <= '@') {
		if(yych <= '/') goto yy86;
		if(yych >= ':') goto yy86;
	} else {
		if(yych <= 'F') goto yy180;
		if(yych <= '`') goto yy86;
		if(yych >= 'g') goto yy86;
	}
yy180:
	++YYCURSOR;
	if(YYLIMIT == YYCURSOR) YYFILL(1);
	yych = *YYCURSOR;
	if(yych <= 'T') {
		if(yych <= '@') {
			if(yych <= '/') goto yy28;
			if(yych <= '9') goto yy180;
			goto yy28;
		} else {
			if(yych <= 'F') goto yy180;
			if(yych == 'L') goto yy163;
			goto yy28;
		}
	} else {
		if(yych <= 'k') {
			if(yych <= 'U') goto yy163;
			if(yych <= '`') goto yy28;
			if(yych <= 'f') goto yy180;
			goto yy28;
		} else {
			if(yych <= 'l') goto yy163;
			if(yych == 'u') goto yy163;
			goto yy28;
		}
	}
yy182:
	++YYCURSOR;
	if(YYLIMIT == YYCURSOR) YYFILL(1);
	yych = *YYCURSOR;
yy183:
	if(yych <= 'Z') {
		if(yych <= '/') goto yy7;
		if(yych <= '9') goto yy182;
		if(yych <= '@') goto yy7;
		goto yy182;
	} else {
		if(yych <= '_') {
			if(yych <= '^') goto yy7;
			goto yy182;
		} else {
			if(yych <= '`') goto yy7;
			if(yych <= 'z') goto yy182;
			goto yy7;
		}
	}
yy184:
	yych = *++YYCURSOR;
	if(yych <= 'O') {
		if(yych == 'I') goto yy192;
		if(yych <= 'N') goto yy183;
		goto yy191;
	} else {
		if(yych <= 'i') {
			if(yych <= 'h') goto yy183;
			goto yy192;
		} else {
			if(yych == 'o') goto yy191;
			goto yy183;
		}
	}
yy185:
	yych = *++YYCURSOR;
	if(yych == 'B') goto yy186;
	if(yych != 'b') goto yy183;
yy186:
	yych = *++YYCURSOR;
	if(yych == 'L') goto yy187;
	if(yych != 'l') goto yy183;
yy187:
	yych = *++YYCURSOR;
	if(yych == 'I') goto yy188;
	if(yych != 'i') goto yy183;
yy188:
	yych = *++YYCURSOR;
	if(yych == 'C') goto yy189;
	if(yych != 'c') goto yy183;
yy189:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '/') goto yy190;
		if(yych <= '9') goto yy182;
		if(yych >= 'A') goto yy182;
	} else {
		if(yych <= '_') {
			if(yych >= '_') goto yy182;
		} else {
			if(yych <= '`') goto yy190;
			if(yych <= 'z') goto yy182;
		}
	}
yy190:
#line 129 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_Public); }
#line 1302 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy191:
	yych = *++YYCURSOR;
	if(yych == 'T') goto yy198;
	if(yych == 't') goto yy198;
	goto yy183;
yy192:
	yych = *++YYCURSOR;
	if(yych == 'V') goto yy193;
	if(yych != 'v') goto yy183;
yy193:
	yych = *++YYCURSOR;
	if(yych == 'A') goto yy194;
	if(yych != 'a') goto yy183;
yy194:
	yych = *++YYCURSOR;
	if(yych == 'T') goto yy195;
	if(yych != 't') goto yy183;
yy195:
	yych = *++YYCURSOR;
	if(yych == 'E') goto yy196;
	if(yych != 'e') goto yy183;
yy196:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '/') goto yy197;
		if(yych <= '9') goto yy182;
		if(yych >= 'A') goto yy182;
	} else {
		if(yych <= '_') {
			if(yych >= '_') goto yy182;
		} else {
			if(yych <= '`') goto yy197;
			if(yych <= 'z') goto yy182;
		}
	}
yy197:
#line 131 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_Private); }
#line 1341 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy198:
	yych = *++YYCURSOR;
	if(yych == 'E') goto yy199;
	if(yych != 'e') goto yy183;
yy199:
	yych = *++YYCURSOR;
	if(yych == 'C') goto yy200;
	if(yych != 'c') goto yy183;
yy200:
	yych = *++YYCURSOR;
	if(yych == 'T') goto yy201;
	if(yych != 't') goto yy183;
yy201:
	yych = *++YYCURSOR;
	if(yych == 'E') goto yy202;
	if(yych != 'e') goto yy183;
yy202:
	yych = *++YYCURSOR;
	if(yych == 'D') goto yy203;
	if(yych != 'd') goto yy183;
yy203:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '/') goto yy204;
		if(yych <= '9') goto yy182;
		if(yych >= 'A') goto yy182;
	} else {
		if(yych <= '_') {
			if(yych >= '_') goto yy182;
		} else {
			if(yych <= '`') goto yy204;
			if(yych <= 'z') goto yy182;
		}
	}
yy204:
#line 130 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_Protected); }
#line 1379 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy205:
	yych = *++YYCURSOR;
	if(yych == 'T') goto yy209;
	if(yych == 't') goto yy209;
	goto yy183;
yy206:
	yych = *++YYCURSOR;
	if(yych == 'T') goto yy207;
	if(yych != 't') goto yy183;
yy207:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '/') goto yy208;
		if(yych <= '9') goto yy182;
		if(yych >= 'A') goto yy182;
	} else {
		if(yych <= '_') {
			if(yych >= '_') goto yy182;
		} else {
			if(yych <= '`') goto yy208;
			if(yych <= 'z') goto yy182;
		}
	}
yy208:
#line 121 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_Out); }
#line 1406 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy209:
	yych = *++YYCURSOR;
	if(yych == 'I') goto yy210;
	if(yych != 'i') goto yy183;
yy210:
	yych = *++YYCURSOR;
	if(yych == 'O') goto yy211;
	if(yych != 'o') goto yy183;
yy211:
	yych = *++YYCURSOR;
	if(yych == 'N') goto yy212;
	if(yych != 'n') goto yy183;
yy212:
	yych = *++YYCURSOR;
	if(yych == 'A') goto yy213;
	if(yych != 'a') goto yy183;
yy213:
	yych = *++YYCURSOR;
	if(yych == 'L') goto yy214;
	if(yych != 'l') goto yy183;
yy214:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '/') goto yy215;
		if(yych <= '9') goto yy182;
		if(yych >= 'A') goto yy182;
	} else {
		if(yych <= '_') {
			if(yych >= '_') goto yy182;
		} else {
			if(yych <= '`') goto yy215;
			if(yych <= 'z') goto yy182;
		}
	}
yy215:
#line 141 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_Optional); }
#line 1444 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy216:
	yych = *++YYCURSOR;
	if(yych == 'R') goto yy229;
	if(yych == 'r') goto yy229;
	goto yy183;
yy217:
	yych = *++YYCURSOR;
	if(yych <= 'U') {
		if(yych == 'A') goto yy219;
		if(yych <= 'T') goto yy183;
	} else {
		if(yych <= 'a') {
			if(yych <= '`') goto yy183;
			goto yy219;
		} else {
			if(yych != 'u') goto yy183;
		}
	}
	yych = *++YYCURSOR;
	if(yych == 'E') goto yy227;
	if(yych == 'e') goto yy227;
	goto yy183;
yy219:
	yych = *++YYCURSOR;
	if(yych == 'N') goto yy220;
	if(yych != 'n') goto yy183;
yy220:
	yych = *++YYCURSOR;
	if(yych == 'S') goto yy221;
	if(yych != 's') goto yy183;
yy221:
	yych = *++YYCURSOR;
	if(yych == 'I') goto yy222;
	if(yych != 'i') goto yy183;
yy222:
	yych = *++YYCURSOR;
	if(yych == 'E') goto yy223;
	if(yych != 'e') goto yy183;
yy223:
	yych = *++YYCURSOR;
	if(yych == 'N') goto yy224;
	if(yych != 'n') goto yy183;
yy224:
	yych = *++YYCURSOR;
	if(yych == 'T') goto yy225;
	if(yych != 't') goto yy183;
yy225:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '/') goto yy226;
		if(yych <= '9') goto yy182;
		if(yych >= 'A') goto yy182;
	} else {
		if(yych <= '_') {
			if(yych >= '_') goto yy182;
		} else {
			if(yych <= '`') goto yy226;
			if(yych <= 'z') goto yy182;
		}
	}
yy226:
#line 125 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_Transient); }
#line 1508 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy227:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '/') goto yy228;
		if(yych <= '9') goto yy182;
		if(yych >= 'A') goto yy182;
	} else {
		if(yych <= '_') {
			if(yych >= '_') goto yy182;
		} else {
			if(yych <= '`') goto yy228;
			if(yych <= 'z') goto yy182;
		}
	}
yy228:
#line 111 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_True); }
#line 1526 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy229:
	yych = *++YYCURSOR;
	if(yych == 'O') goto yy230;
	if(yych != 'o') goto yy183;
yy230:
	yych = *++YYCURSOR;
	if(yych == 'W') goto yy231;
	if(yych != 'w') goto yy183;
yy231:
	yych = *++YYCURSOR;
	if(yych == 'S') goto yy232;
	if(yych != 's') goto yy183;
yy232:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '/') goto yy233;
		if(yych <= '9') goto yy182;
		if(yych >= 'A') goto yy182;
	} else {
		if(yych <= '_') {
			if(yych >= '_') goto yy182;
		} else {
			if(yych <= '`') goto yy233;
			if(yych <= 'z') goto yy182;
		}
	}
yy233:
#line 127 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_Throws); }
#line 1556 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy234:
	yych = *++YYCURSOR;
	if(yych == 'S') goto yy264;
	if(yych == 's') goto yy264;
	goto yy183;
yy235:
	yych = *++YYCURSOR;
	if(yych == 'T') goto yy259;
	if(yych == 't') goto yy259;
	goto yy183;
yy236:
	yych = *++YYCURSOR;
	if(yych == 'I') goto yy253;
	if(yych == 'i') goto yy253;
	goto yy183;
yy237:
	yych = *++YYCURSOR;
	if(yych == 'G') goto yy247;
	if(yych == 'g') goto yy247;
	goto yy183;
yy238:
	yych = *++YYCURSOR;
	if(yych == 'R') goto yy243;
	if(yych == 'r') goto yy243;
	goto yy183;
yy239:
	yych = *++YYCURSOR;
	if(yych == 'T') goto yy240;
	if(yych != 't') goto yy183;
yy240:
	yych = *++YYCURSOR;
	if(yych == 'O') goto yy241;
	if(yych != 'o') goto yy183;
yy241:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '/') goto yy242;
		if(yych <= '9') goto yy182;
		if(yych >= 'A') goto yy182;
	} else {
		if(yych <= '_') {
			if(yych >= '_') goto yy182;
		} else {
			if(yych <= '`') goto yy242;
			if(yych <= 'z') goto yy182;
		}
	}
yy242:
#line 116 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_Auto); }
#line 1607 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy243:
	yych = *++YYCURSOR;
	if(yych == 'A') goto yy244;
	if(yych != 'a') goto yy183;
yy244:
	yych = *++YYCURSOR;
	if(yych == 'Y') goto yy245;
	if(yych != 'y') goto yy183;
yy245:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '/') goto yy246;
		if(yych <= '9') goto yy182;
		if(yych >= 'A') goto yy182;
	} else {
		if(yych <= '_') {
			if(yych >= '_') goto yy182;
		} else {
			if(yych <= '`') goto yy246;
			if(yych <= 'z') goto yy182;
		}
	}
yy246:
#line 103 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_Array); }
#line 1633 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy247:
	yych = *++YYCURSOR;
	if(yych == 'L') goto yy248;
	if(yych != 'l') goto yy183;
yy248:
	yych = *++YYCURSOR;
	if(yych == 'E') goto yy249;
	if(yych != 'e') goto yy183;
yy249:
	yych = *++YYCURSOR;
	if(yych != '_') goto yy183;
	yych = *++YYCURSOR;
	if(yych == 'T') goto yy251;
	if(yych != 't') goto yy183;
yy251:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '/') goto yy252;
		if(yych <= '9') goto yy182;
		if(yych >= 'A') goto yy182;
	} else {
		if(yych <= '_') {
			if(yych >= '_') goto yy182;
		} else {
			if(yych <= '`') goto yy252;
			if(yych <= 'z') goto yy182;
		}
	}
yy252:
#line 158 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_Angle_t); }
#line 1665 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy253:
	yych = *++YYCURSOR;
	if(yych == 'G') goto yy254;
	if(yych != 'g') goto yy183;
yy254:
	yych = *++YYCURSOR;
	if(yych == 'N') goto yy255;
	if(yych != 'n') goto yy183;
yy255:
	yych = *++YYCURSOR;
	if(yych == 'O') goto yy256;
	if(yych != 'o') goto yy183;
yy256:
	yych = *++YYCURSOR;
	if(yych == 'F') goto yy257;
	if(yych != 'f') goto yy183;
yy257:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '/') goto yy258;
		if(yych <= '9') goto yy182;
		if(yych >= 'A') goto yy182;
	} else {
		if(yych <= '_') {
			if(yych >= '_') goto yy182;
		} else {
			if(yych <= '`') goto yy258;
			if(yych <= 'z') goto yy182;
		}
	}
yy258:
#line 106 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_AlignOf); }
#line 1699 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy259:
	yych = *++YYCURSOR;
	if(yych == 'I') goto yy260;
	if(yych != 'i') goto yy183;
yy260:
	yych = *++YYCURSOR;
	if(yych == 'O') goto yy261;
	if(yych != 'o') goto yy183;
yy261:
	yych = *++YYCURSOR;
	if(yych == 'N') goto yy262;
	if(yych != 'n') goto yy183;
yy262:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '/') goto yy263;
		if(yych <= '9') goto yy182;
		if(yych >= 'A') goto yy182;
	} else {
		if(yych <= '_') {
			if(yych >= '_') goto yy182;
		} else {
			if(yych <= '`') goto yy263;
			if(yych <= 'z') goto yy182;
		}
	}
yy263:
#line 153 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_Action); }
#line 1729 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy264:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '@') {
			if(yych <= '/') goto yy265;
			if(yych <= '9') goto yy182;
		} else {
			if(yych == 'T') goto yy266;
			goto yy182;
		}
	} else {
		if(yych <= '`') {
			if(yych == '_') goto yy182;
		} else {
			if(yych == 't') goto yy266;
			if(yych <= 'z') goto yy182;
		}
	}
yy265:
#line 159 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_Abs); }
#line 1751 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy266:
	yych = *++YYCURSOR;
	if(yych == 'R') goto yy267;
	if(yych != 'r') goto yy183;
yy267:
	yych = *++YYCURSOR;
	if(yych == 'A') goto yy268;
	if(yych != 'a') goto yy183;
yy268:
	yych = *++YYCURSOR;
	if(yych == 'C') goto yy269;
	if(yych != 'c') goto yy183;
yy269:
	yych = *++YYCURSOR;
	if(yych == 'T') goto yy270;
	if(yych != 't') goto yy183;
yy270:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '/') goto yy271;
		if(yych <= '9') goto yy182;
		if(yych >= 'A') goto yy182;
	} else {
		if(yych <= '_') {
			if(yych >= '_') goto yy182;
		} else {
			if(yych <= '`') goto yy271;
			if(yych <= 'z') goto yy182;
		}
	}
yy271:
#line 109 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_Abstract); }
#line 1785 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy272:
	yych = *++YYCURSOR;
	if(yych <= 'T') {
		if(yych == 'M') goto yy280;
		if(yych <= 'S') goto yy183;
		goto yy281;
	} else {
		if(yych <= 'm') {
			if(yych <= 'l') goto yy183;
			goto yy280;
		} else {
			if(yych == 't') goto yy281;
			goto yy183;
		}
	}
yy273:
	yych = *++YYCURSOR;
	if(yych == 'W') goto yy278;
	if(yych == 'w') goto yy278;
	goto yy183;
yy274:
	yych = *++YYCURSOR;
	if(yych == 'N') goto yy275;
	if(yych != 'n') goto yy183;
yy275:
	yych = *++YYCURSOR;
	if(yych == 'E') goto yy276;
	if(yych != 'e') goto yy183;
yy276:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '/') goto yy277;
		if(yych <= '9') goto yy182;
		if(yych >= 'A') goto yy182;
	} else {
		if(yych <= '_') {
			if(yych >= '_') goto yy182;
		} else {
			if(yych <= '`') goto yy277;
			if(yych <= 'z') goto yy182;
		}
	}
yy277:
#line 113 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_None); }
#line 1831 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy278:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '/') goto yy279;
		if(yych <= '9') goto yy182;
		if(yych >= 'A') goto yy182;
	} else {
		if(yych <= '_') {
			if(yych >= '_') goto yy182;
		} else {
			if(yych <= '`') goto yy279;
			if(yych <= 'z') goto yy182;
		}
	}
yy279:
#line 114 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_New); }
#line 1849 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy280:
	yych = *++YYCURSOR;
	if(yych == 'E') goto yy286;
	if(yych == 'e') goto yy286;
	goto yy183;
yy281:
	yych = *++YYCURSOR;
	if(yych == 'I') goto yy282;
	if(yych != 'i') goto yy183;
yy282:
	yych = *++YYCURSOR;
	if(yych == 'V') goto yy283;
	if(yych != 'v') goto yy183;
yy283:
	yych = *++YYCURSOR;
	if(yych == 'E') goto yy284;
	if(yych != 'e') goto yy183;
yy284:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '/') goto yy285;
		if(yych <= '9') goto yy182;
		if(yych >= 'A') goto yy182;
	} else {
		if(yych <= '_') {
			if(yych >= '_') goto yy182;
		} else {
			if(yych <= '`') goto yy285;
			if(yych <= 'z') goto yy182;
		}
	}
yy285:
#line 119 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_Native); }
#line 1884 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy286:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '/') goto yy287;
		if(yych <= '9') goto yy182;
		if(yych >= 'A') goto yy182;
	} else {
		if(yych <= '_') {
			if(yych >= '_') goto yy182;
		} else {
			if(yych <= '`') goto yy287;
			if(yych <= 'z') goto yy182;
		}
	}
yy287:
#line 96 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_Name); }
#line 1902 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy288:
	yych = *++YYCURSOR;
	if(yych == 'P') goto yy293;
	if(yych == 'p') goto yy293;
	goto yy183;
yy289:
	yych = *++YYCURSOR;
	if(yych == 'D') goto yy290;
	if(yych != 'd') goto yy183;
yy290:
	yych = *++YYCURSOR;
	if(yych == 'E') goto yy291;
	if(yych != 'e') goto yy183;
yy291:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '/') goto yy292;
		if(yych <= '9') goto yy182;
		if(yych >= 'A') goto yy182;
	} else {
		if(yych <= '_') {
			if(yych >= '_') goto yy182;
		} else {
			if(yych <= '`') goto yy292;
			if(yych <= 'z') goto yy182;
		}
	}
yy292:
#line 94 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_Mode); }
#line 1933 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy293:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '/') goto yy294;
		if(yych <= '9') goto yy182;
		if(yych >= 'A') goto yy182;
	} else {
		if(yych <= '_') {
			if(yych >= '_') goto yy182;
		} else {
			if(yych <= '`') goto yy294;
			if(yych <= 'z') goto yy182;
		}
	}
yy294:
#line 102 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_Map); }
#line 1951 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy295:
	yych = *++YYCURSOR;
	if(yych == 'T') goto yy308;
	if(yych == 't') goto yy308;
	goto yy183;
yy296:
	yych = *++YYCURSOR;
	if(yych <= 'N') {
		if(yych == 'C') goto yy298;
		if(yych <= 'M') goto yy183;
	} else {
		if(yych <= 'c') {
			if(yych <= 'b') goto yy183;
			goto yy298;
		} else {
			if(yych != 'n') goto yy183;
		}
	}
	yych = *++YYCURSOR;
	if(yych == 'G') goto yy306;
	if(yych == 'g') goto yy306;
	goto yy183;
yy298:
	yych = *++YYCURSOR;
	if(yych == 'A') goto yy299;
	if(yych != 'a') goto yy183;
yy299:
	yych = *++YYCURSOR;
	if(yych == 'L') goto yy300;
	if(yych != 'l') goto yy183;
yy300:
	yych = *++YYCURSOR;
	if(yych == 'I') goto yy301;
	if(yych != 'i') goto yy183;
yy301:
	yych = *++YYCURSOR;
	if(yych == 'Z') goto yy302;
	if(yych != 'z') goto yy183;
yy302:
	yych = *++YYCURSOR;
	if(yych == 'E') goto yy303;
	if(yych != 'e') goto yy183;
yy303:
	yych = *++YYCURSOR;
	if(yych == 'D') goto yy304;
	if(yych != 'd') goto yy183;
yy304:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '/') goto yy305;
		if(yych <= '9') goto yy182;
		if(yych >= 'A') goto yy182;
	} else {
		if(yych <= '_') {
			if(yych >= '_') goto yy182;
		} else {
			if(yych <= '`') goto yy305;
			if(yych <= 'z') goto yy182;
		}
	}
yy305:
#line 135 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_Localized); }
#line 2015 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy306:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '/') goto yy307;
		if(yych <= '9') goto yy182;
		if(yych >= 'A') goto yy182;
	} else {
		if(yych <= '_') {
			if(yych >= '_') goto yy182;
		} else {
			if(yych <= '`') goto yy307;
			if(yych <= 'z') goto yy182;
		}
	}
yy307:
#line 89 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_Long); }
#line 2033 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy308:
	yych = *++YYCURSOR;
	if(yych == 'E') goto yy309;
	if(yych != 'e') goto yy183;
yy309:
	yych = *++YYCURSOR;
	if(yych == 'N') goto yy310;
	if(yych != 'n') goto yy183;
yy310:
	yych = *++YYCURSOR;
	if(yych == 'T') goto yy311;
	if(yych != 't') goto yy183;
yy311:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '/') goto yy312;
		if(yych <= '9') goto yy182;
		if(yych >= 'A') goto yy182;
	} else {
		if(yych <= '_') {
			if(yych >= '_') goto yy182;
		} else {
			if(yych <= '`') goto yy312;
			if(yych <= 'z') goto yy182;
		}
	}
yy312:
#line 136 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_Latent); }
#line 2063 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy313:
	yych = *++YYCURSOR;
	if(yych == 'I') goto yy314;
	if(yych != 'i') goto yy183;
yy314:
	yych = *++YYCURSOR;
	if(yych == 'L') goto yy315;
	if(yych != 'l') goto yy183;
yy315:
	yych = *++YYCURSOR;
	if(yych == 'E') goto yy316;
	if(yych != 'e') goto yy183;
yy316:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '/') goto yy317;
		if(yych <= '9') goto yy182;
		if(yych >= 'A') goto yy182;
	} else {
		if(yych <= '_') {
			if(yych >= '_') goto yy182;
		} else {
			if(yych <= '`') goto yy317;
			if(yych <= 'z') goto yy182;
		}
	}
yy317:
#line 76 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_While); }
#line 2093 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy318:
	yych = *++YYCURSOR;
	if(yych == 'R') goto yy343;
	if(yych == 'r') goto yy343;
	goto yy183;
yy319:
	yych = *++YYCURSOR;
	if(yych == 'C') goto yy338;
	if(yych == 'c') goto yy338;
	goto yy183;
yy320:
	yych = *++YYCURSOR;
	if(yych == 'R') goto yy332;
	if(yych == 'r') goto yy332;
	goto yy183;
yy321:
	yych = *++YYCURSOR;
	if(yych <= 'L') {
		if(yych == 'I') goto yy323;
		if(yych <= 'K') goto yy183;
	} else {
		if(yych <= 'i') {
			if(yych <= 'h') goto yy183;
			goto yy323;
		} else {
			if(yych != 'l') goto yy183;
		}
	}
	yych = *++YYCURSOR;
	if(yych == 'A') goto yy326;
	if(yych == 'a') goto yy326;
	goto yy183;
yy323:
	yych = *++YYCURSOR;
	if(yych == 'D') goto yy324;
	if(yych != 'd') goto yy183;
yy324:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '/') goto yy325;
		if(yych <= '9') goto yy182;
		if(yych >= 'A') goto yy182;
	} else {
		if(yych <= '_') {
			if(yych >= '_') goto yy182;
		} else {
			if(yych <= '`') goto yy325;
			if(yych <= 'z') goto yy182;
		}
	}
yy325:
#line 91 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_Void); }
#line 2147 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy326:
	yych = *++YYCURSOR;
	if(yych == 'T') goto yy327;
	if(yych != 't') goto yy183;
yy327:
	yych = *++YYCURSOR;
	if(yych == 'I') goto yy328;
	if(yych != 'i') goto yy183;
yy328:
	yych = *++YYCURSOR;
	if(yych == 'L') goto yy329;
	if(yych != 'l') goto yy183;
yy329:
	yych = *++YYCURSOR;
	if(yych == 'E') goto yy330;
	if(yych != 'e') goto yy183;
yy330:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '/') goto yy331;
		if(yych <= '9') goto yy182;
		if(yych >= 'A') goto yy182;
	} else {
		if(yych <= '_') {
			if(yych >= '_') goto yy182;
		} else {
			if(yych <= '`') goto yy331;
			if(yych <= 'z') goto yy182;
		}
	}
yy331:
#line 75 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_Volatile); }
#line 2181 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy332:
	yych = *++YYCURSOR;
	if(yych == 'T') goto yy333;
	if(yych != 't') goto yy183;
yy333:
	yych = *++YYCURSOR;
	if(yych == 'U') goto yy334;
	if(yych != 'u') goto yy183;
yy334:
	yych = *++YYCURSOR;
	if(yych == 'A') goto yy335;
	if(yych != 'a') goto yy183;
yy335:
	yych = *++YYCURSOR;
	if(yych == 'L') goto yy336;
	if(yych != 'l') goto yy183;
yy336:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '/') goto yy337;
		if(yych <= '9') goto yy182;
		if(yych >= 'A') goto yy182;
	} else {
		if(yych <= '_') {
			if(yych >= '_') goto yy182;
		} else {
			if(yych <= '`') goto yy337;
			if(yych <= 'z') goto yy182;
		}
	}
yy337:
#line 143 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_Virtual); }
#line 2215 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy338:
	yych = *++YYCURSOR;
	if(yych == 'T') goto yy339;
	if(yych != 't') goto yy183;
yy339:
	yych = *++YYCURSOR;
	if(yych == 'O') goto yy340;
	if(yych != 'o') goto yy183;
yy340:
	yych = *++YYCURSOR;
	if(yych == 'R') goto yy341;
	if(yych != 'r') goto yy183;
yy341:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '/') goto yy342;
		if(yych <= '9') goto yy182;
		if(yych >= 'A') goto yy182;
	} else {
		if(yych <= '_') {
			if(yych >= '_') goto yy182;
		} else {
			if(yych <= '`') goto yy342;
			if(yych <= 'z') goto yy182;
		}
	}
yy342:
#line 101 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_Vector); }
#line 2245 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy343:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '/') goto yy344;
		if(yych <= '9') goto yy182;
		if(yych >= 'A') goto yy182;
	} else {
		if(yych <= '_') {
			if(yych >= '_') goto yy182;
		} else {
			if(yych <= '`') goto yy344;
			if(yych <= 'z') goto yy182;
		}
	}
yy344:
#line 120 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_Var); }
#line 2263 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy345:
	yych = *++YYCURSOR;
	if(yych == 'N') goto yy362;
	if(yych == 'n') goto yy362;
	goto yy183;
yy346:
	yych = *++YYCURSOR;
	if(yych == 'O') goto yy358;
	if(yych == 'o') goto yy358;
	goto yy183;
yy347:
	yych = *++YYCURSOR;
	if(yych == 'T') goto yy354;
	if(yych == 't') goto yy354;
	goto yy183;
yy348:
	yych = *++YYCURSOR;
	if(yych == 'H') goto yy349;
	if(yych != 'h') goto yy183;
yy349:
	yych = *++YYCURSOR;
	if(yych == 'O') goto yy350;
	if(yych != 'o') goto yy183;
yy350:
	yych = *++YYCURSOR;
	if(yych == 'R') goto yy351;
	if(yych != 'r') goto yy183;
yy351:
	yych = *++YYCURSOR;
	if(yych == 'T') goto yy352;
	if(yych != 't') goto yy183;
yy352:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '/') goto yy353;
		if(yych <= '9') goto yy182;
		if(yych >= 'A') goto yy182;
	} else {
		if(yych <= '_') {
			if(yych >= '_') goto yy182;
		} else {
			if(yych <= '`') goto yy353;
			if(yych <= 'z') goto yy182;
		}
	}
yy353:
#line 86 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_UShort); }
#line 2312 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy354:
	yych = *++YYCURSOR;
	if(yych == 'I') goto yy355;
	if(yych != 'i') goto yy183;
yy355:
	yych = *++YYCURSOR;
	if(yych == 'L') goto yy356;
	if(yych != 'l') goto yy183;
yy356:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '/') goto yy357;
		if(yych <= '9') goto yy182;
		if(yych >= 'A') goto yy182;
	} else {
		if(yych <= '_') {
			if(yych >= '_') goto yy182;
		} else {
			if(yych <= '`') goto yy357;
			if(yych <= 'z') goto yy182;
		}
	}
yy357:
#line 74 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_Until); }
#line 2338 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy358:
	yych = *++YYCURSOR;
	if(yych == 'N') goto yy359;
	if(yych != 'n') goto yy183;
yy359:
	yych = *++YYCURSOR;
	if(yych == 'G') goto yy360;
	if(yych != 'g') goto yy183;
yy360:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '/') goto yy361;
		if(yych <= '9') goto yy182;
		if(yych >= 'A') goto yy182;
	} else {
		if(yych <= '_') {
			if(yych >= '_') goto yy182;
		} else {
			if(yych <= '`') goto yy361;
			if(yych <= 'z') goto yy182;
		}
	}
yy361:
#line 90 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_ULong); }
#line 2364 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy362:
	yych = *++YYCURSOR;
	if(yych == 'T') goto yy363;
	if(yych != 't') goto yy183;
yy363:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '/') goto yy364;
		if(yych <= '9') goto yy182;
		if(yych >= 'A') goto yy182;
	} else {
		if(yych <= '_') {
			if(yych >= '_') goto yy182;
		} else {
			if(yych <= '`') goto yy364;
			if(yych <= 'z') goto yy182;
		}
	}
yy364:
#line 88 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_UInt); }
#line 2386 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy365:
	yych = *++YYCURSOR;
	if(yych == 'Y') goto yy424;
	if(yych == 'y') goto yy424;
	goto yy183;
yy366:
	yych = *++YYCURSOR;
	if(yych == 'L') goto yy421;
	if(yych == 'l') goto yy421;
	goto yy183;
yy367:
	yych = *++YYCURSOR;
	if(yych == 'O') goto yy417;
	if(yych == 'o') goto yy417;
	goto yy183;
yy368:
	yych = *++YYCURSOR;
	if(yych <= 'Z') {
		if(yych == 'N') goto yy406;
		if(yych <= 'Y') goto yy183;
		goto yy405;
	} else {
		if(yych <= 'n') {
			if(yych <= 'm') goto yy183;
			goto yy406;
		} else {
			if(yych == 'z') goto yy405;
			goto yy183;
		}
	}
yy369:
	yych = *++YYCURSOR;
	if(yych == 'U') goto yy401;
	if(yych == 'u') goto yy401;
	goto yy183;
yy370:
	yych = *++YYCURSOR;
	if(yych <= 'R') {
		if(yych <= 'N') {
			if(yych == 'A') goto yy383;
			goto yy183;
		} else {
			if(yych <= 'O') goto yy384;
			if(yych <= 'Q') goto yy183;
			goto yy382;
		}
	} else {
		if(yych <= 'n') {
			if(yych == 'a') goto yy383;
			goto yy183;
		} else {
			if(yych <= 'o') goto yy384;
			if(yych == 'r') goto yy382;
			goto yy183;
		}
	}
yy371:
	yych = *++YYCURSOR;
	if(yych == 'P') goto yy378;
	if(yych == 'p') goto yy378;
	goto yy183;
yy372:
	yych = *++YYCURSOR;
	if(yych == 'I') goto yy373;
	if(yych != 'i') goto yy183;
yy373:
	yych = *++YYCURSOR;
	if(yych == 'T') goto yy374;
	if(yych != 't') goto yy183;
yy374:
	yych = *++YYCURSOR;
	if(yych == 'C') goto yy375;
	if(yych != 'c') goto yy183;
yy375:
	yych = *++YYCURSOR;
	if(yych == 'H') goto yy376;
	if(yych != 'h') goto yy183;
yy376:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '/') goto yy377;
		if(yych <= '9') goto yy182;
		if(yych >= 'A') goto yy182;
	} else {
		if(yych <= '_') {
			if(yych >= '_') goto yy182;
		} else {
			if(yych <= '`') goto yy377;
			if(yych <= 'z') goto yy182;
		}
	}
yy377:
#line 73 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_Switch); }
#line 2481 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy378:
	yych = *++YYCURSOR;
	if(yych == 'E') goto yy379;
	if(yych != 'e') goto yy183;
yy379:
	yych = *++YYCURSOR;
	if(yych == 'R') goto yy380;
	if(yych != 'r') goto yy183;
yy380:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '/') goto yy381;
		if(yych <= '9') goto yy182;
		if(yych >= 'A') goto yy182;
	} else {
		if(yych <= '_') {
			if(yych >= '_') goto yy182;
		} else {
			if(yych <= '`') goto yy381;
			if(yych <= 'z') goto yy182;
		}
	}
yy381:
#line 144 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_Super); }
#line 2507 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy382:
	yych = *++YYCURSOR;
	if(yych <= 'U') {
		if(yych == 'I') goto yy393;
		if(yych <= 'T') goto yy183;
		goto yy394;
	} else {
		if(yych <= 'i') {
			if(yych <= 'h') goto yy183;
			goto yy393;
		} else {
			if(yych == 'u') goto yy394;
			goto yy183;
		}
	}
yy383:
	yych = *++YYCURSOR;
	if(yych == 'T') goto yy387;
	if(yych == 't') goto yy387;
	goto yy183;
yy384:
	yych = *++YYCURSOR;
	if(yych == 'P') goto yy385;
	if(yych != 'p') goto yy183;
yy385:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '/') goto yy386;
		if(yych <= '9') goto yy182;
		if(yych >= 'A') goto yy182;
	} else {
		if(yych <= '_') {
			if(yych >= '_') goto yy182;
		} else {
			if(yych <= '`') goto yy386;
			if(yych <= 'z') goto yy182;
		}
	}
yy386:
#line 147 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_Stop); }
#line 2549 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy387:
	yych = *++YYCURSOR;
	if(yych <= 'I') {
		if(yych == 'E') goto yy388;
		if(yych <= 'H') goto yy183;
		goto yy390;
	} else {
		if(yych <= 'e') {
			if(yych <= 'd') goto yy183;
		} else {
			if(yych == 'i') goto yy390;
			goto yy183;
		}
	}
yy388:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '/') goto yy389;
		if(yych <= '9') goto yy182;
		if(yych >= 'A') goto yy182;
	} else {
		if(yych <= '_') {
			if(yych >= '_') goto yy182;
		} else {
			if(yych <= '`') goto yy389;
			if(yych <= 'z') goto yy182;
		}
	}
yy389:
#line 99 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_State); }
#line 2581 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy390:
	yych = *++YYCURSOR;
	if(yych == 'C') goto yy391;
	if(yych != 'c') goto yy183;
yy391:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '/') goto yy392;
		if(yych <= '9') goto yy182;
		if(yych >= 'A') goto yy182;
	} else {
		if(yych <= '_') {
			if(yych >= '_') goto yy182;
		} else {
			if(yych <= '`') goto yy392;
			if(yych <= 'z') goto yy182;
		}
	}
yy392:
#line 124 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_Static); }
#line 2603 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy393:
	yych = *++YYCURSOR;
	if(yych == 'N') goto yy398;
	if(yych == 'n') goto yy398;
	goto yy183;
yy394:
	yych = *++YYCURSOR;
	if(yych == 'C') goto yy395;
	if(yych != 'c') goto yy183;
yy395:
	yych = *++YYCURSOR;
	if(yych == 'T') goto yy396;
	if(yych != 't') goto yy183;
yy396:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '/') goto yy397;
		if(yych <= '9') goto yy182;
		if(yych >= 'A') goto yy182;
	} else {
		if(yych <= '_') {
			if(yych >= '_') goto yy182;
		} else {
			if(yych <= '`') goto yy397;
			if(yych <= 'z') goto yy182;
		}
	}
yy397:
#line 92 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_Struct); }
#line 2634 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy398:
	yych = *++YYCURSOR;
	if(yych == 'G') goto yy399;
	if(yych != 'g') goto yy183;
yy399:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '/') goto yy400;
		if(yych <= '9') goto yy182;
		if(yych >= 'A') goto yy182;
	} else {
		if(yych <= '_') {
			if(yych >= '_') goto yy182;
		} else {
			if(yych <= '`') goto yy400;
			if(yych <= 'z') goto yy182;
		}
	}
yy400:
#line 97 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_String); }
#line 2656 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy401:
	yych = *++YYCURSOR;
	if(yych == 'N') goto yy402;
	if(yych != 'n') goto yy183;
yy402:
	yych = *++YYCURSOR;
	if(yych == 'D') goto yy403;
	if(yych != 'd') goto yy183;
yy403:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '/') goto yy404;
		if(yych <= '9') goto yy182;
		if(yych >= 'A') goto yy182;
	} else {
		if(yych <= '_') {
			if(yych >= '_') goto yy182;
		} else {
			if(yych <= '`') goto yy404;
			if(yych <= 'z') goto yy182;
		}
	}
yy404:
#line 98 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_Sound); }
#line 2682 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy405:
	yych = *++YYCURSOR;
	if(yych == 'E') goto yy413;
	if(yych == 'e') goto yy413;
	goto yy183;
yy406:
	yych = *++YYCURSOR;
	if(yych == 'G') goto yy407;
	if(yych != 'g') goto yy183;
yy407:
	yych = *++YYCURSOR;
	if(yych == 'U') goto yy408;
	if(yych != 'u') goto yy183;
yy408:
	yych = *++YYCURSOR;
	if(yych == 'L') goto yy409;
	if(yych != 'l') goto yy183;
yy409:
	yych = *++YYCURSOR;
	if(yych == 'A') goto yy410;
	if(yych != 'a') goto yy183;
yy410:
	yych = *++YYCURSOR;
	if(yych == 'R') goto yy411;
	if(yych != 'r') goto yy183;
yy411:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '/') goto yy412;
		if(yych <= '9') goto yy182;
		if(yych >= 'A') goto yy182;
	} else {
		if(yych <= '_') {
			if(yych >= '_') goto yy182;
		} else {
			if(yych <= '`') goto yy412;
			if(yych <= 'z') goto yy182;
		}
	}
yy412:
#line 137 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_Singular); }
#line 2725 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy413:
	yych = *++YYCURSOR;
	if(yych == 'O') goto yy414;
	if(yych != 'o') goto yy183;
yy414:
	yych = *++YYCURSOR;
	if(yych == 'F') goto yy415;
	if(yych != 'f') goto yy183;
yy415:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '/') goto yy416;
		if(yych <= '9') goto yy182;
		if(yych >= 'A') goto yy182;
	} else {
		if(yych <= '_') {
			if(yych >= '_') goto yy182;
		} else {
			if(yych <= '`') goto yy416;
			if(yych <= 'z') goto yy182;
		}
	}
yy416:
#line 105 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_SizeOf); }
#line 2751 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy417:
	yych = *++YYCURSOR;
	if(yych == 'R') goto yy418;
	if(yych != 'r') goto yy183;
yy418:
	yych = *++YYCURSOR;
	if(yych == 'T') goto yy419;
	if(yych != 't') goto yy183;
yy419:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '/') goto yy420;
		if(yych <= '9') goto yy182;
		if(yych >= 'A') goto yy182;
	} else {
		if(yych <= '_') {
			if(yych >= '_') goto yy182;
		} else {
			if(yych <= '`') goto yy420;
			if(yych <= 'z') goto yy182;
		}
	}
yy420:
#line 85 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_Short); }
#line 2777 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy421:
	yych = *++YYCURSOR;
	if(yych == 'F') goto yy422;
	if(yych != 'f') goto yy183;
yy422:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '/') goto yy423;
		if(yych <= '9') goto yy182;
		if(yych >= 'A') goto yy182;
	} else {
		if(yych <= '_') {
			if(yych >= '_') goto yy182;
		} else {
			if(yych <= '`') goto yy423;
			if(yych <= 'z') goto yy182;
		}
	}
yy423:
#line 146 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_Self); }
#line 2799 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy424:
	yych = *++YYCURSOR;
	if(yych == 'T') goto yy425;
	if(yych != 't') goto yy183;
yy425:
	yych = *++YYCURSOR;
	if(yych == 'E') goto yy426;
	if(yych != 'e') goto yy183;
yy426:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '/') goto yy427;
		if(yych <= '9') goto yy182;
		if(yych >= 'A') goto yy182;
	} else {
		if(yych <= '_') {
			if(yych >= '_') goto yy182;
		} else {
			if(yych <= '`') goto yy427;
			if(yych <= 'z') goto yy182;
		}
	}
yy427:
#line 84 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_SByte); }
#line 2825 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy428:
	yych = *++YYCURSOR;
	if(yych == 'N') goto yy444;
	if(yych == 'n') goto yy444;
	goto yy183;
yy429:
	yych = *++YYCURSOR;
	if(yych <= 'T') {
		if(yych <= 'O') {
			if(yych == 'F') goto yy431;
			goto yy183;
		} else {
			if(yych <= 'P') goto yy433;
			if(yych <= 'S') goto yy183;
		}
	} else {
		if(yych <= 'o') {
			if(yych == 'f') goto yy431;
			goto yy183;
		} else {
			if(yych <= 'p') goto yy433;
			if(yych != 't') goto yy183;
		}
	}
	yych = *++YYCURSOR;
	if(yych == 'U') goto yy440;
	if(yych == 'u') goto yy440;
	goto yy183;
yy431:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '/') goto yy432;
		if(yych <= '9') goto yy182;
		if(yych >= 'A') goto yy182;
	} else {
		if(yych <= '_') {
			if(yych >= '_') goto yy182;
		} else {
			if(yych <= '`') goto yy432;
			if(yych <= 'z') goto yy182;
		}
	}
yy432:
#line 122 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_Ref); }
#line 2871 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy433:
	yych = *++YYCURSOR;
	if(yych == 'L') goto yy434;
	if(yych != 'l') goto yy183;
yy434:
	yych = *++YYCURSOR;
	if(yych == 'A') goto yy435;
	if(yych != 'a') goto yy183;
yy435:
	yych = *++YYCURSOR;
	if(yych == 'C') goto yy436;
	if(yych != 'c') goto yy183;
yy436:
	yych = *++YYCURSOR;
	if(yych == 'E') goto yy437;
	if(yych != 'e') goto yy183;
yy437:
	yych = *++YYCURSOR;
	if(yych == 'S') goto yy438;
	if(yych != 's') goto yy183;
yy438:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '/') goto yy439;
		if(yych <= '9') goto yy182;
		if(yych >= 'A') goto yy182;
	} else {
		if(yych <= '_') {
			if(yych >= '_') goto yy182;
		} else {
			if(yych <= '`') goto yy439;
			if(yych <= 'z') goto yy182;
		}
	}
yy439:
#line 150 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_Replaces); }
#line 2909 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy440:
	yych = *++YYCURSOR;
	if(yych == 'R') goto yy441;
	if(yych != 'r') goto yy183;
yy441:
	yych = *++YYCURSOR;
	if(yych == 'N') goto yy442;
	if(yych != 'n') goto yy183;
yy442:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '/') goto yy443;
		if(yych <= '9') goto yy182;
		if(yych >= 'A') goto yy182;
	} else {
		if(yych <= '_') {
			if(yych >= '_') goto yy182;
		} else {
			if(yych <= '`') goto yy443;
			if(yych <= 'z') goto yy182;
		}
	}
yy443:
#line 72 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_Return); }
#line 2935 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy444:
	yych = *++YYCURSOR;
	if(yych == 'D') goto yy445;
	if(yych != 'd') goto yy183;
yy445:
	yych = *++YYCURSOR;
	if(yych == 'O') goto yy446;
	if(yych != 'o') goto yy183;
yy446:
	yych = *++YYCURSOR;
	if(yych == 'M') goto yy447;
	if(yych != 'm') goto yy183;
yy447:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'P') {
		if(yych <= '2') {
			if(yych <= '/') goto yy448;
			if(yych <= '1') goto yy182;
			goto yy449;
		} else {
			if(yych <= '9') goto yy182;
			if(yych <= '@') goto yy448;
			if(yych <= 'O') goto yy182;
			goto yy451;
		}
	} else {
		if(yych <= '`') {
			if(yych <= 'Z') goto yy182;
			if(yych == '_') goto yy182;
		} else {
			if(yych == 'p') goto yy451;
			if(yych <= 'z') goto yy182;
		}
	}
yy448:
#line 160 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_Random); }
#line 2973 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy449:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '/') goto yy450;
		if(yych <= '9') goto yy182;
		if(yych >= 'A') goto yy182;
	} else {
		if(yych <= '_') {
			if(yych >= '_') goto yy182;
		} else {
			if(yych <= '`') goto yy450;
			if(yych <= 'z') goto yy182;
		}
	}
yy450:
#line 161 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_Random2); }
#line 2991 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy451:
	yych = *++YYCURSOR;
	if(yych == 'I') goto yy452;
	if(yych != 'i') goto yy183;
yy452:
	yych = *++YYCURSOR;
	if(yych == 'C') goto yy453;
	if(yych != 'c') goto yy183;
yy453:
	yych = *++YYCURSOR;
	if(yych == 'K') goto yy454;
	if(yych != 'k') goto yy183;
yy454:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '/') goto yy455;
		if(yych <= '9') goto yy182;
		if(yych >= 'A') goto yy182;
	} else {
		if(yych <= '_') {
			if(yych >= '_') goto yy182;
		} else {
			if(yych <= '`') goto yy455;
			if(yych <= 'z') goto yy182;
		}
	}
yy455:
#line 163 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_RandomPick); }
#line 3021 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy456:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '/') goto yy457;
		if(yych <= '9') goto yy182;
		if(yych >= 'A') goto yy182;
	} else {
		if(yych <= '_') {
			if(yych >= '_') goto yy182;
		} else {
			if(yych <= '`') goto yy457;
			if(yych <= 'z') goto yy182;
		}
	}
yy457:
#line 71 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_If); }
#line 3039 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy458:
	yych = *++YYCURSOR;
	if(yych == 'N') goto yy482;
	if(yych == 'n') goto yy482;
	goto yy183;
yy459:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '@') {
			if(yych <= '/') goto yy460;
			if(yych <= '9') goto yy182;
		} else {
			if(yych <= 'R') goto yy182;
			if(yych <= 'S') goto yy473;
			if(yych <= 'T') goto yy471;
			goto yy182;
		}
	} else {
		if(yych <= 'r') {
			if(yych == '_') goto yy182;
			if(yych >= 'a') goto yy182;
		} else {
			if(yych <= 's') goto yy473;
			if(yych <= 't') goto yy471;
			if(yych <= 'z') goto yy182;
		}
	}
yy460:
#line 104 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_In); }
#line 3070 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy461:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '/') goto yy462;
		if(yych <= '9') goto yy182;
		if(yych >= 'A') goto yy182;
	} else {
		if(yych <= '_') {
			if(yych >= '_') goto yy182;
		} else {
			if(yych <= '`') goto yy462;
			if(yych <= 'z') goto yy182;
		}
	}
yy462:
#line 149 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_Is); }
#line 3088 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy463:
	yych = *++YYCURSOR;
	if(yych == 'E') goto yy464;
	if(yych != 'e') goto yy183;
yy464:
	yych = *++YYCURSOR;
	if(yych == 'R') goto yy465;
	if(yych != 'r') goto yy183;
yy465:
	yych = *++YYCURSOR;
	if(yych == 'A') goto yy466;
	if(yych != 'a') goto yy183;
yy466:
	yych = *++YYCURSOR;
	if(yych == 'T') goto yy467;
	if(yych != 't') goto yy183;
yy467:
	yych = *++YYCURSOR;
	if(yych == 'O') goto yy468;
	if(yych != 'o') goto yy183;
yy468:
	yych = *++YYCURSOR;
	if(yych == 'R') goto yy469;
	if(yych != 'r') goto yy183;
yy469:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '/') goto yy470;
		if(yych <= '9') goto yy182;
		if(yych >= 'A') goto yy182;
	} else {
		if(yych <= '_') {
			if(yych >= '_') goto yy182;
		} else {
			if(yych <= '`') goto yy470;
			if(yych <= 'z') goto yy182;
		}
	}
yy470:
#line 140 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_Iterator); }
#line 3130 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy471:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '/') goto yy472;
		if(yych <= '9') goto yy182;
		if(yych >= 'A') goto yy182;
	} else {
		if(yych <= '_') {
			if(yych >= '_') goto yy182;
		} else {
			if(yych <= '`') goto yy472;
			if(yych <= 'z') goto yy182;
		}
	}
yy472:
#line 87 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_Int); }
#line 3148 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy473:
	yych = *++YYCURSOR;
	if(yych == 'T') goto yy474;
	if(yych != 't') goto yy183;
yy474:
	yych = *++YYCURSOR;
	if(yych == 'A') goto yy475;
	if(yych != 'a') goto yy183;
yy475:
	yych = *++YYCURSOR;
	if(yych == 'N') goto yy476;
	if(yych != 'n') goto yy183;
yy476:
	yych = *++YYCURSOR;
	if(yych == 'C') goto yy477;
	if(yych != 'c') goto yy183;
yy477:
	yych = *++YYCURSOR;
	if(yych == 'E') goto yy478;
	if(yych != 'e') goto yy183;
yy478:
	yych = *++YYCURSOR;
	if(yych == 'O') goto yy479;
	if(yych != 'o') goto yy183;
yy479:
	yych = *++YYCURSOR;
	if(yych == 'F') goto yy480;
	if(yych != 'f') goto yy183;
yy480:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '/') goto yy481;
		if(yych <= '9') goto yy182;
		if(yych >= 'A') goto yy182;
	} else {
		if(yych <= '_') {
			if(yych >= '_') goto yy182;
		} else {
			if(yych <= '`') goto yy481;
			if(yych <= 'z') goto yy182;
		}
	}
yy481:
#line 115 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_InstanceOf); }
#line 3194 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy482:
	yych = *++YYCURSOR;
	if(yych == 'O') goto yy483;
	if(yych != 'o') goto yy183;
yy483:
	yych = *++YYCURSOR;
	if(yych == 'R') goto yy484;
	if(yych != 'r') goto yy183;
yy484:
	yych = *++YYCURSOR;
	if(yych == 'E') goto yy485;
	if(yych != 'e') goto yy183;
yy485:
	yych = *++YYCURSOR;
	if(yych == 'S') goto yy486;
	if(yych != 's') goto yy183;
yy486:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '/') goto yy487;
		if(yych <= '9') goto yy182;
		if(yych >= 'A') goto yy182;
	} else {
		if(yych <= '_') {
			if(yych >= '_') goto yy182;
		} else {
			if(yych <= '`') goto yy487;
			if(yych <= 'z') goto yy182;
		}
	}
yy487:
#line 134 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_Ignores); }
#line 3228 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy488:
	yych = *++YYCURSOR;
	if(yych == 'O') goto yy493;
	if(yych == 'o') goto yy493;
	goto yy183;
yy489:
	yych = *++YYCURSOR;
	if(yych == 'T') goto yy490;
	if(yych != 't') goto yy183;
yy490:
	yych = *++YYCURSOR;
	if(yych == 'O') goto yy491;
	if(yych != 'o') goto yy183;
yy491:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '/') goto yy492;
		if(yych <= '9') goto yy182;
		if(yych >= 'A') goto yy182;
	} else {
		if(yych <= '_') {
			if(yych >= '_') goto yy182;
		} else {
			if(yych <= '`') goto yy492;
			if(yych <= 'z') goto yy182;
		}
	}
yy492:
#line 70 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_Goto); }
#line 3259 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy493:
	yych = *++YYCURSOR;
	if(yych == 'B') goto yy494;
	if(yych != 'b') goto yy183;
yy494:
	yych = *++YYCURSOR;
	if(yych == 'A') goto yy495;
	if(yych != 'a') goto yy183;
yy495:
	yych = *++YYCURSOR;
	if(yych == 'L') goto yy496;
	if(yych != 'l') goto yy183;
yy496:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '/') goto yy497;
		if(yych <= '9') goto yy182;
		if(yych >= 'A') goto yy182;
	} else {
		if(yych <= '_') {
			if(yych >= '_') goto yy182;
		} else {
			if(yych <= '`') goto yy497;
			if(yych <= 'z') goto yy182;
		}
	}
yy497:
#line 145 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_Global); }
#line 3289 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy498:
	yych = *++YYCURSOR;
	if(yych == 'L') goto yy535;
	if(yych == 'l') goto yy535;
	goto yy183;
yy499:
	yych = *++YYCURSOR;
	if(yych <= 'X') {
		if(yych == 'N') goto yy525;
		if(yych <= 'W') goto yy183;
		goto yy526;
	} else {
		if(yych <= 'n') {
			if(yych <= 'm') goto yy183;
			goto yy525;
		} else {
			if(yych == 'x') goto yy526;
			goto yy183;
		}
	}
yy500:
	yych = *++YYCURSOR;
	if(yych == 'O') goto yy521;
	if(yych == 'o') goto yy521;
	goto yy183;
yy501:
	yych = *++YYCURSOR;
	if(yych == 'R') goto yy514;
	if(yych == 'r') goto yy514;
	goto yy183;
yy502:
	yych = *++YYCURSOR;
	if(yych == 'A') goto yy503;
	if(yych != 'a') goto yy183;
yy503:
	yych = *++YYCURSOR;
	if(yych == 'N') goto yy504;
	if(yych != 'n') goto yy183;
yy504:
	yych = *++YYCURSOR;
	if(yych == 'D') goto yy505;
	if(yych != 'd') goto yy183;
yy505:
	yych = *++YYCURSOR;
	if(yych == 'O') goto yy506;
	if(yych != 'o') goto yy183;
yy506:
	yych = *++YYCURSOR;
	if(yych == 'M') goto yy507;
	if(yych != 'm') goto yy183;
yy507:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '@') {
			if(yych <= '/') goto yy508;
			if(yych <= '9') goto yy182;
		} else {
			if(yych == 'P') goto yy509;
			goto yy182;
		}
	} else {
		if(yych <= '`') {
			if(yych == '_') goto yy182;
		} else {
			if(yych == 'p') goto yy509;
			if(yych <= 'z') goto yy182;
		}
	}
yy508:
#line 162 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_FRandom); }
#line 3361 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy509:
	yych = *++YYCURSOR;
	if(yych == 'I') goto yy510;
	if(yych != 'i') goto yy183;
yy510:
	yych = *++YYCURSOR;
	if(yych == 'C') goto yy511;
	if(yych != 'c') goto yy183;
yy511:
	yych = *++YYCURSOR;
	if(yych == 'K') goto yy512;
	if(yych != 'k') goto yy183;
yy512:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '/') goto yy513;
		if(yych <= '9') goto yy182;
		if(yych >= 'A') goto yy182;
	} else {
		if(yych <= '_') {
			if(yych >= '_') goto yy182;
		} else {
			if(yych <= '`') goto yy513;
			if(yych <= 'z') goto yy182;
		}
	}
yy513:
#line 164 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_FRandomPick); }
#line 3391 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy514:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '@') {
			if(yych <= '/') goto yy515;
			if(yych <= '9') goto yy182;
		} else {
			if(yych == 'E') goto yy516;
			goto yy182;
		}
	} else {
		if(yych <= '`') {
			if(yych == '_') goto yy182;
		} else {
			if(yych == 'e') goto yy516;
			if(yych <= 'z') goto yy182;
		}
	}
yy515:
#line 69 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_For); }
#line 3413 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy516:
	yych = *++YYCURSOR;
	if(yych == 'A') goto yy517;
	if(yych != 'a') goto yy183;
yy517:
	yych = *++YYCURSOR;
	if(yych == 'C') goto yy518;
	if(yych != 'c') goto yy183;
yy518:
	yych = *++YYCURSOR;
	if(yych == 'H') goto yy519;
	if(yych != 'h') goto yy183;
yy519:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '/') goto yy520;
		if(yych <= '9') goto yy182;
		if(yych >= 'A') goto yy182;
	} else {
		if(yych <= '_') {
			if(yych >= '_') goto yy182;
		} else {
			if(yych <= '`') goto yy520;
			if(yych <= 'z') goto yy182;
		}
	}
yy520:
#line 110 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_ForEach); }
#line 3443 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy521:
	yych = *++YYCURSOR;
	if(yych == 'A') goto yy522;
	if(yych != 'a') goto yy183;
yy522:
	yych = *++YYCURSOR;
	if(yych == 'T') goto yy523;
	if(yych != 't') goto yy183;
yy523:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '/') goto yy524;
		if(yych <= '9') goto yy182;
		if(yych >= 'A') goto yy182;
	} else {
		if(yych <= '_') {
			if(yych >= '_') goto yy182;
		} else {
			if(yych <= '`') goto yy524;
			if(yych <= 'z') goto yy182;
		}
	}
yy524:
#line 80 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_Float); }
#line 3469 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy525:
	yych = *++YYCURSOR;
	if(yych == 'A') goto yy532;
	if(yych == 'a') goto yy532;
	goto yy183;
yy526:
	yych = *++YYCURSOR;
	if(yych == 'E') goto yy527;
	if(yych != 'e') goto yy183;
yy527:
	yych = *++YYCURSOR;
	if(yych == 'D') goto yy528;
	if(yych != 'd') goto yy183;
yy528:
	yych = *++YYCURSOR;
	if(yych != '_') goto yy183;
	yych = *++YYCURSOR;
	if(yych == 'T') goto yy530;
	if(yych != 't') goto yy183;
yy530:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '/') goto yy531;
		if(yych <= '9') goto yy182;
		if(yych >= 'A') goto yy182;
	} else {
		if(yych <= '_') {
			if(yych >= '_') goto yy182;
		} else {
			if(yych <= '`') goto yy531;
			if(yych <= 'z') goto yy182;
		}
	}
yy531:
#line 157 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_Fixed_t); }
#line 3506 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy532:
	yych = *++YYCURSOR;
	if(yych == 'L') goto yy533;
	if(yych != 'l') goto yy183;
yy533:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '/') goto yy534;
		if(yych <= '9') goto yy182;
		if(yych >= 'A') goto yy182;
	} else {
		if(yych <= '_') {
			if(yych >= '_') goto yy182;
		} else {
			if(yych <= '`') goto yy534;
			if(yych <= 'z') goto yy182;
		}
	}
yy534:
#line 126 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_Final); }
#line 3528 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy535:
	yych = *++YYCURSOR;
	if(yych == 'S') goto yy536;
	if(yych != 's') goto yy183;
yy536:
	yych = *++YYCURSOR;
	if(yych == 'E') goto yy537;
	if(yych != 'e') goto yy183;
yy537:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '/') goto yy538;
		if(yych <= '9') goto yy182;
		if(yych >= 'A') goto yy182;
	} else {
		if(yych <= '_') {
			if(yych >= '_') goto yy182;
		} else {
			if(yych <= '`') goto yy538;
			if(yych <= 'z') goto yy182;
		}
	}
yy538:
#line 112 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_False); }
#line 3554 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy539:
	yych = *++YYCURSOR;
	if(yych == 'S') goto yy564;
	if(yych == 's') goto yy564;
	goto yy183;
yy540:
	yych = *++YYCURSOR;
	if(yych == 'U') goto yy561;
	if(yych == 'u') goto yy561;
	goto yy183;
yy541:
	yych = *++YYCURSOR;
	if(yych == 'E') goto yy557;
	if(yych == 'e') goto yy557;
	goto yy183;
yy542:
	yych = *++YYCURSOR;
	if(yych <= 'T') {
		if(yych <= 'O') {
			if(yych != 'E') goto yy183;
		} else {
			if(yych <= 'P') goto yy545;
			if(yych <= 'S') goto yy183;
			goto yy544;
		}
	} else {
		if(yych <= 'o') {
			if(yych != 'e') goto yy183;
		} else {
			if(yych <= 'p') goto yy545;
			if(yych == 't') goto yy544;
			goto yy183;
		}
	}
	yych = *++YYCURSOR;
	if(yych == 'C') goto yy555;
	if(yych == 'c') goto yy555;
	goto yy183;
yy544:
	yych = *++YYCURSOR;
	if(yych == 'E') goto yy550;
	if(yych == 'e') goto yy550;
	goto yy183;
yy545:
	yych = *++YYCURSOR;
	if(yych == 'O') goto yy546;
	if(yych != 'o') goto yy183;
yy546:
	yych = *++YYCURSOR;
	if(yych == 'R') goto yy547;
	if(yych != 'r') goto yy183;
yy547:
	yych = *++YYCURSOR;
	if(yych == 'T') goto yy548;
	if(yych != 't') goto yy183;
yy548:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '/') goto yy549;
		if(yych <= '9') goto yy182;
		if(yych >= 'A') goto yy182;
	} else {
		if(yych <= '_') {
			if(yych >= '_') goto yy182;
		} else {
			if(yych <= '`') goto yy549;
			if(yych <= 'z') goto yy182;
		}
	}
yy549:
#line 142 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_Export); }
#line 3627 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy550:
	yych = *++YYCURSOR;
	if(yych == 'N') goto yy551;
	if(yych != 'n') goto yy183;
yy551:
	yych = *++YYCURSOR;
	if(yych == 'D') goto yy552;
	if(yych != 'd') goto yy183;
yy552:
	yych = *++YYCURSOR;
	if(yych == 'S') goto yy553;
	if(yych != 's') goto yy183;
yy553:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '/') goto yy554;
		if(yych <= '9') goto yy182;
		if(yych >= 'A') goto yy182;
	} else {
		if(yych <= '_') {
			if(yych >= '_') goto yy182;
		} else {
			if(yych <= '`') goto yy554;
			if(yych <= 'z') goto yy182;
		}
	}
yy554:
#line 128 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_Extends); }
#line 3657 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy555:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '/') goto yy556;
		if(yych <= '9') goto yy182;
		if(yych >= 'A') goto yy182;
	} else {
		if(yych <= '_') {
			if(yych >= '_') goto yy182;
		} else {
			if(yych <= '`') goto yy556;
			if(yych <= 'z') goto yy182;
		}
	}
yy556:
#line 117 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_Exec); }
#line 3675 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy557:
	yych = *++YYCURSOR;
	if(yych == 'N') goto yy558;
	if(yych != 'n') goto yy183;
yy558:
	yych = *++YYCURSOR;
	if(yych == 'T') goto yy559;
	if(yych != 't') goto yy183;
yy559:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '/') goto yy560;
		if(yych <= '9') goto yy182;
		if(yych >= 'A') goto yy182;
	} else {
		if(yych <= '_') {
			if(yych >= '_') goto yy182;
		} else {
			if(yych <= '`') goto yy560;
			if(yych <= 'z') goto yy182;
		}
	}
yy560:
#line 123 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_Event); }
#line 3701 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy561:
	yych = *++YYCURSOR;
	if(yych == 'M') goto yy562;
	if(yych != 'm') goto yy183;
yy562:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '/') goto yy563;
		if(yych <= '9') goto yy182;
		if(yych >= 'A') goto yy182;
	} else {
		if(yych <= '_') {
			if(yych >= '_') goto yy182;
		} else {
			if(yych <= '`') goto yy563;
			if(yych <= 'z') goto yy182;
		}
	}
yy563:
#line 95 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_Enum); }
#line 3723 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy564:
	yych = *++YYCURSOR;
	if(yych == 'E') goto yy565;
	if(yych != 'e') goto yy183;
yy565:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '/') goto yy566;
		if(yych <= '9') goto yy182;
		if(yych >= 'A') goto yy182;
	} else {
		if(yych <= '_') {
			if(yych >= '_') goto yy182;
		} else {
			if(yych <= '`') goto yy566;
			if(yych <= 'z') goto yy182;
		}
	}
yy566:
#line 68 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_Else); }
#line 3745 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy567:
	yych = *++YYCURSOR;
	if(yych == 'F') goto yy577;
	if(yych == 'f') goto yy577;
	goto yy183;
yy568:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '@') {
			if(yych <= '/') goto yy569;
			if(yych <= '9') goto yy182;
		} else {
			if(yych <= 'S') goto yy182;
			if(yych <= 'T') goto yy571;
			if(yych <= 'U') goto yy570;
			goto yy182;
		}
	} else {
		if(yych <= 's') {
			if(yych == '_') goto yy182;
			if(yych >= 'a') goto yy182;
		} else {
			if(yych <= 't') goto yy571;
			if(yych <= 'u') goto yy570;
			if(yych <= 'z') goto yy182;
		}
	}
yy569:
#line 67 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_Do); }
#line 3776 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy570:
	yych = *++YYCURSOR;
	if(yych == 'B') goto yy573;
	if(yych == 'b') goto yy573;
	goto yy183;
yy571:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '/') goto yy572;
		if(yych <= '9') goto yy182;
		if(yych >= 'A') goto yy182;
	} else {
		if(yych <= '_') {
			if(yych >= '_') goto yy182;
		} else {
			if(yych <= '`') goto yy572;
			if(yych <= 'z') goto yy182;
		}
	}
yy572:
#line 132 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_Dot); }
#line 3799 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy573:
	yych = *++YYCURSOR;
	if(yych == 'L') goto yy574;
	if(yych != 'l') goto yy183;
yy574:
	yych = *++YYCURSOR;
	if(yych == 'E') goto yy575;
	if(yych != 'e') goto yy183;
yy575:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '/') goto yy576;
		if(yych <= '9') goto yy182;
		if(yych >= 'A') goto yy182;
	} else {
		if(yych <= '_') {
			if(yych >= '_') goto yy182;
		} else {
			if(yych <= '`') goto yy576;
			if(yych <= 'z') goto yy182;
		}
	}
yy576:
#line 81 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_Double); }
#line 3825 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy577:
	yych = *++YYCURSOR;
	if(yych == 'A') goto yy578;
	if(yych != 'a') goto yy183;
yy578:
	yych = *++YYCURSOR;
	if(yych == 'U') goto yy579;
	if(yych != 'u') goto yy183;
yy579:
	yych = *++YYCURSOR;
	if(yych == 'L') goto yy580;
	if(yych != 'l') goto yy183;
yy580:
	yych = *++YYCURSOR;
	if(yych == 'T') goto yy581;
	if(yych != 't') goto yy183;
yy581:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '@') {
			if(yych <= '/') goto yy582;
			if(yych <= '9') goto yy182;
		} else {
			if(yych == 'P') goto yy583;
			goto yy182;
		}
	} else {
		if(yych <= '`') {
			if(yych == '_') goto yy182;
		} else {
			if(yych == 'p') goto yy583;
			if(yych <= 'z') goto yy182;
		}
	}
yy582:
#line 66 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_Default); }
#line 3863 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy583:
	yych = *++YYCURSOR;
	if(yych == 'R') goto yy584;
	if(yych != 'r') goto yy183;
yy584:
	yych = *++YYCURSOR;
	if(yych == 'O') goto yy585;
	if(yych != 'o') goto yy183;
yy585:
	yych = *++YYCURSOR;
	if(yych == 'P') goto yy586;
	if(yych != 'p') goto yy183;
yy586:
	yych = *++YYCURSOR;
	if(yych == 'E') goto yy587;
	if(yych != 'e') goto yy183;
yy587:
	yych = *++YYCURSOR;
	if(yych == 'R') goto yy588;
	if(yych != 'r') goto yy183;
yy588:
	yych = *++YYCURSOR;
	if(yych == 'T') goto yy589;
	if(yych != 't') goto yy183;
yy589:
	yych = *++YYCURSOR;
	if(yych == 'I') goto yy590;
	if(yych != 'i') goto yy183;
yy590:
	yych = *++YYCURSOR;
	if(yych == 'E') goto yy591;
	if(yych != 'e') goto yy183;
yy591:
	yych = *++YYCURSOR;
	if(yych == 'S') goto yy592;
	if(yych != 's') goto yy183;
yy592:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '/') goto yy593;
		if(yych <= '9') goto yy182;
		if(yych >= 'A') goto yy182;
	} else {
		if(yych <= '_') {
			if(yych >= '_') goto yy182;
		} else {
			if(yych <= '`') goto yy593;
			if(yych <= 'z') goto yy182;
		}
	}
yy593:
#line 118 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_DefaultProperties); }
#line 3917 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy594:
	yych = *++YYCURSOR;
	if(yych == 'S') goto yy633;
	if(yych == 's') goto yy633;
	goto yy183;
yy595:
	yych = *++YYCURSOR;
	if(yych == 'A') goto yy630;
	if(yych == 'a') goto yy630;
	goto yy183;
yy596:
	yych = *++YYCURSOR;
	if(yych == 'A') goto yy626;
	if(yych == 'a') goto yy626;
	goto yy183;
yy597:
	yych = *++YYCURSOR;
	if(yych <= 'N') {
		if(yych <= 'K') {
			if(yych == 'E') goto yy605;
			goto yy183;
		} else {
			if(yych <= 'L') goto yy604;
			if(yych <= 'M') goto yy183;
			goto yy603;
		}
	} else {
		if(yych <= 'k') {
			if(yych == 'e') goto yy605;
			goto yy183;
		} else {
			if(yych <= 'l') goto yy604;
			if(yych == 'n') goto yy603;
			goto yy183;
		}
	}
yy598:
	yych = *++YYCURSOR;
	if(yych == 'O') goto yy599;
	if(yych != 'o') goto yy183;
yy599:
	yych = *++YYCURSOR;
	if(yych == 'S') goto yy600;
	if(yych != 's') goto yy183;
yy600:
	yych = *++YYCURSOR;
	if(yych == 'S') goto yy601;
	if(yych != 's') goto yy183;
yy601:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '/') goto yy602;
		if(yych <= '9') goto yy182;
		if(yych >= 'A') goto yy182;
	} else {
		if(yych <= '_') {
			if(yych >= '_') goto yy182;
		} else {
			if(yych <= '`') goto yy602;
			if(yych <= 'z') goto yy182;
		}
	}
yy602:
#line 133 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_Cross); }
#line 3983 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy603:
	yych = *++YYCURSOR;
	if(yych <= 'T') {
		if(yych <= 'F') {
			if(yych <= 'E') goto yy183;
			goto yy613;
		} else {
			if(yych <= 'R') goto yy183;
			if(yych <= 'S') goto yy614;
			goto yy615;
		}
	} else {
		if(yych <= 'r') {
			if(yych == 'f') goto yy613;
			goto yy183;
		} else {
			if(yych <= 's') goto yy614;
			if(yych <= 't') goto yy615;
			goto yy183;
		}
	}
yy604:
	yych = *++YYCURSOR;
	if(yych == 'O') goto yy610;
	if(yych == 'o') goto yy610;
	goto yy183;
yy605:
	yych = *++YYCURSOR;
	if(yych == 'R') goto yy606;
	if(yych != 'r') goto yy183;
yy606:
	yych = *++YYCURSOR;
	if(yych == 'C') goto yy607;
	if(yych != 'c') goto yy183;
yy607:
	yych = *++YYCURSOR;
	if(yych == 'E') goto yy608;
	if(yych != 'e') goto yy183;
yy608:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '/') goto yy609;
		if(yych <= '9') goto yy182;
		if(yych >= 'A') goto yy182;
	} else {
		if(yych <= '_') {
			if(yych >= '_') goto yy182;
		} else {
			if(yych <= '`') goto yy609;
			if(yych <= 'z') goto yy182;
		}
	}
yy609:
#line 139 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_Coerce); }
#line 4039 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy610:
	yych = *++YYCURSOR;
	if(yych == 'R') goto yy611;
	if(yych != 'r') goto yy183;
yy611:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '/') goto yy612;
		if(yych <= '9') goto yy182;
		if(yych >= 'A') goto yy182;
	} else {
		if(yych <= '_') {
			if(yych >= '_') goto yy182;
		} else {
			if(yych <= '`') goto yy612;
			if(yych <= 'z') goto yy182;
		}
	}
yy612:
#line 100 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_Color); }
#line 4061 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy613:
	yych = *++YYCURSOR;
	if(yych == 'I') goto yy623;
	if(yych == 'i') goto yy623;
	goto yy183;
yy614:
	yych = *++YYCURSOR;
	if(yych == 'T') goto yy621;
	if(yych == 't') goto yy621;
	goto yy183;
yy615:
	yych = *++YYCURSOR;
	if(yych == 'I') goto yy616;
	if(yych != 'i') goto yy183;
yy616:
	yych = *++YYCURSOR;
	if(yych == 'N') goto yy617;
	if(yych != 'n') goto yy183;
yy617:
	yych = *++YYCURSOR;
	if(yych == 'U') goto yy618;
	if(yych != 'u') goto yy183;
yy618:
	yych = *++YYCURSOR;
	if(yych == 'E') goto yy619;
	if(yych != 'e') goto yy183;
yy619:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '/') goto yy620;
		if(yych <= '9') goto yy182;
		if(yych >= 'A') goto yy182;
	} else {
		if(yych <= '_') {
			if(yych >= '_') goto yy182;
		} else {
			if(yych <= '`') goto yy620;
			if(yych <= 'z') goto yy182;
		}
	}
yy620:
#line 65 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_Continue); }
#line 4105 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy621:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '/') goto yy622;
		if(yych <= '9') goto yy182;
		if(yych >= 'A') goto yy182;
	} else {
		if(yych <= '_') {
			if(yych >= '_') goto yy182;
		} else {
			if(yych <= '`') goto yy622;
			if(yych <= 'z') goto yy182;
		}
	}
yy622:
#line 64 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_Const); }
#line 4123 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy623:
	yych = *++YYCURSOR;
	if(yych == 'G') goto yy624;
	if(yych != 'g') goto yy183;
yy624:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '/') goto yy625;
		if(yych <= '9') goto yy182;
		if(yych >= 'A') goto yy182;
	} else {
		if(yych <= '_') {
			if(yych >= '_') goto yy182;
		} else {
			if(yych <= '`') goto yy625;
			if(yych <= 'z') goto yy182;
		}
	}
yy625:
#line 138 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_Config); }
#line 4145 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy626:
	yych = *++YYCURSOR;
	if(yych == 'S') goto yy627;
	if(yych != 's') goto yy183;
yy627:
	yych = *++YYCURSOR;
	if(yych == 'S') goto yy628;
	if(yych != 's') goto yy183;
yy628:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '/') goto yy629;
		if(yych <= '9') goto yy182;
		if(yych >= 'A') goto yy182;
	} else {
		if(yych <= '_') {
			if(yych >= '_') goto yy182;
		} else {
			if(yych <= '`') goto yy629;
			if(yych <= 'z') goto yy182;
		}
	}
yy629:
#line 93 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_Class); }
#line 4171 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy630:
	yych = *++YYCURSOR;
	if(yych == 'R') goto yy631;
	if(yych != 'r') goto yy183;
yy631:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '/') goto yy632;
		if(yych <= '9') goto yy182;
		if(yych >= 'A') goto yy182;
	} else {
		if(yych <= '_') {
			if(yych >= '_') goto yy182;
		} else {
			if(yych <= '`') goto yy632;
			if(yych <= 'z') goto yy182;
		}
	}
yy632:
#line 82 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_Char); }
#line 4193 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy633:
	yych = *++YYCURSOR;
	if(yych == 'E') goto yy634;
	if(yych != 'e') goto yy183;
yy634:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '/') goto yy635;
		if(yych <= '9') goto yy182;
		if(yych >= 'A') goto yy182;
	} else {
		if(yych <= '_') {
			if(yych >= '_') goto yy182;
		} else {
			if(yych <= '`') goto yy635;
			if(yych <= 'z') goto yy182;
		}
	}
yy635:
#line 63 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_Case); }
#line 4215 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy636:
	yych = *++YYCURSOR;
	if(yych == 'O') goto yy646;
	if(yych == 'o') goto yy646;
	goto yy183;
yy637:
	yych = *++YYCURSOR;
	if(yych == 'E') goto yy642;
	if(yych == 'e') goto yy642;
	goto yy183;
yy638:
	yych = *++YYCURSOR;
	if(yych == 'T') goto yy639;
	if(yych != 't') goto yy183;
yy639:
	yych = *++YYCURSOR;
	if(yych == 'E') goto yy640;
	if(yych != 'e') goto yy183;
yy640:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '/') goto yy641;
		if(yych <= '9') goto yy182;
		if(yych >= 'A') goto yy182;
	} else {
		if(yych <= '_') {
			if(yych >= '_') goto yy182;
		} else {
			if(yych <= '`') goto yy641;
			if(yych <= 'z') goto yy182;
		}
	}
yy641:
#line 83 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_Byte); }
#line 4251 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy642:
	yych = *++YYCURSOR;
	if(yych == 'A') goto yy643;
	if(yych != 'a') goto yy183;
yy643:
	yych = *++YYCURSOR;
	if(yych == 'K') goto yy644;
	if(yych != 'k') goto yy183;
yy644:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '/') goto yy645;
		if(yych <= '9') goto yy182;
		if(yych >= 'A') goto yy182;
	} else {
		if(yych <= '_') {
			if(yych >= '_') goto yy182;
		} else {
			if(yych <= '`') goto yy645;
			if(yych <= 'z') goto yy182;
		}
	}
yy645:
#line 62 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_Break); }
#line 4277 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy646:
	yych = *++YYCURSOR;
	if(yych == 'L') goto yy647;
	if(yych != 'l') goto yy183;
yy647:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= 'Z') {
		if(yych <= '/') goto yy648;
		if(yych <= '9') goto yy182;
		if(yych >= 'A') goto yy182;
	} else {
		if(yych <= '_') {
			if(yych >= '_') goto yy182;
		} else {
			if(yych <= '`') goto yy648;
			if(yych <= 'z') goto yy182;
		}
	}
yy648:
#line 79 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_Bool); }
#line 4299 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy649:
	yych = *++YYCURSOR;
	if(yych == 'N') goto yy667;
	if(yych == 'n') goto yy667;
	goto yy86;
yy650:
	yych = *++YYCURSOR;
	if(yych == 'n') goto yy660;
	goto yy86;
yy651:
	yych = *++YYCURSOR;
	if(yych != 'e') goto yy86;
	yych = *++YYCURSOR;
	if(yych != 'g') goto yy86;
	yych = *++YYCURSOR;
	if(yych != 'i') goto yy86;
	yych = *++YYCURSOR;
	if(yych != 'o') goto yy86;
	yych = *++YYCURSOR;
	if(yych != 'n') goto yy86;
yy656:
	++YYCURSOR;
	if(YYLIMIT == YYCURSOR) YYFILL(1);
	yych = *YYCURSOR;
	if(yych != 0x0A) goto yy656;
	++YYCURSOR;
#line 59 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ goto newline; }
#line 4328 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy660:
	yych = *++YYCURSOR;
	if(yych != 'd') goto yy86;
	yych = *++YYCURSOR;
	if(yych != 'r') goto yy86;
	yych = *++YYCURSOR;
	if(yych != 'e') goto yy86;
	yych = *++YYCURSOR;
	if(yych != 'g') goto yy86;
	yych = *++YYCURSOR;
	if(yych != 'i') goto yy86;
	yych = *++YYCURSOR;
	if(yych != 'o') goto yy86;
	yych = *++YYCURSOR;
	if(yych == 'n') goto yy656;
	goto yy86;
yy667:
	yych = *++YYCURSOR;
	if(yych == 'C') goto yy668;
	if(yych != 'c') goto yy86;
yy668:
	yych = *++YYCURSOR;
	if(yych == 'L') goto yy669;
	if(yych != 'l') goto yy86;
yy669:
	yych = *++YYCURSOR;
	if(yych == 'U') goto yy670;
	if(yych != 'u') goto yy86;
yy670:
	yych = *++YYCURSOR;
	if(yych == 'D') goto yy671;
	if(yych != 'd') goto yy86;
yy671:
	yych = *++YYCURSOR;
	if(yych == 'E') goto yy672;
	if(yych != 'e') goto yy86;
yy672:
	++YYCURSOR;
#line 156 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_Include); }
#line 4369 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy674:
	++YYCURSOR;
#line 188 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ RET(TK_DivEq); }
#line 4374 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy676:
	++YYCURSOR;
	if(YYLIMIT == YYCURSOR) YYFILL(1);
	yych = *YYCURSOR;
	if(yych == 0x0A) goto yy680;
	goto yy676;
yy678:
	++YYCURSOR;
#line 56 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ goto comment; }
#line 4385 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy680:
	++YYCURSOR;
#line 57 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ goto newline; }
#line 4390 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
}
#line 239 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"

	}
	if (!CMode)	// The classic Hexen scanner.
	{
	
#line 4398 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
{
	YYCTYPE yych;
	unsigned int yyaccept = 0;
	if((YYLIMIT - YYCURSOR) < 10) YYFILL(10);
	yych = *YYCURSOR;
	if(yych <= '.') {
		if(yych <= ' ') {
			if(yych == 0x0A) goto yy691;
			goto yy689;
		} else {
			if(yych <= '!') goto yy697;
			if(yych <= '"') goto yy693;
			if(yych <= '#') goto yy688;
			goto yy697;
		}
	} else {
		if(yych <= '<') {
			if(yych <= '/') goto yy685;
			if(yych == ';') goto yy687;
			goto yy697;
		} else {
			if(yych <= '=') goto yy695;
			if(yych <= 'z') goto yy697;
			if(yych <= '}') goto yy695;
			goto yy697;
		}
	}
yy684:
#line 256 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ goto normal_token; }
#line 4429 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy685:
	yyaccept = 0;
	yych = *(YYMARKER = ++YYCURSOR);
	if(yych <= '/') {
		if(yych <= '"') {
			if(yych == '!') goto yy702;
		} else {
			if(yych == '*') goto yy732;
			if(yych <= '.') goto yy702;
			goto yy728;
		}
	} else {
		if(yych <= '<') {
			if(yych != ';') goto yy702;
		} else {
			if(yych <= '=') goto yy686;
			if(yych <= 'z') goto yy702;
			if(yych >= '~') goto yy702;
		}
	}
yy686:
#line 258 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ goto normal_token; }
#line 4453 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy687:
	yyaccept = 0;
	yych = *(YYMARKER = ++YYCURSOR);
	goto yy729;
yy688:
	yyaccept = 1;
	yych = *(YYMARKER = ++YYCURSOR);
	if(yych == 'e') goto yy706;
	if(yych == 'r') goto yy707;
	goto yy701;
yy689:
	++YYCURSOR;
	yych = *YYCURSOR;
	goto yy705;
yy690:
#line 249 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ goto std1; }
#line 4471 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy691:
	++YYCURSOR;
#line 250 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ goto newline; }
#line 4476 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy693:
	++YYCURSOR;
#line 251 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ goto string; }
#line 4481 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy695:
	++YYCURSOR;
#line 253 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ goto normal_token; }
#line 4486 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy697:
	yyaccept = 1;
	yych = *(YYMARKER = ++YYCURSOR);
	goto yy701;
yy698:
	++YYCURSOR;
	if(YYLIMIT == YYCURSOR) YYFILL(1);
	yych = *YYCURSOR;
	if(yych <= '/') {
		if(yych <= '"') {
			if(yych == '!') goto yy702;
		} else {
			if(yych == '*') goto yy699;
			if(yych <= '.') goto yy702;
		}
	} else {
		if(yych <= '<') {
			if(yych != ';') goto yy702;
		} else {
			if(yych <= '=') goto yy699;
			if(yych <= 'z') goto yy702;
			if(yych >= '~') goto yy702;
		}
	}
yy699:
	YYCURSOR = YYMARKER;
	if(yyaccept <= 0) {
		goto yy686;
	} else {
		goto yy684;
	}
yy700:
	yyaccept = 1;
	YYMARKER = ++YYCURSOR;
	if(YYLIMIT == YYCURSOR) YYFILL(1);
	yych = *YYCURSOR;
yy701:
	if(yych <= ':') {
		if(yych <= '"') {
			if(yych == '!') goto yy700;
			goto yy684;
		} else {
			if(yych == '/') goto yy698;
			goto yy700;
		}
	} else {
		if(yych <= '=') {
			if(yych == '<') goto yy700;
			goto yy684;
		} else {
			if(yych <= 'z') goto yy700;
			if(yych <= '}') goto yy684;
			goto yy700;
		}
	}
yy702:
	yyaccept = 1;
	YYMARKER = ++YYCURSOR;
	if(YYLIMIT == YYCURSOR) YYFILL(1);
	yych = *YYCURSOR;
	if(yych <= ':') {
		if(yych <= '"') {
			if(yych == '!') goto yy702;
			goto yy684;
		} else {
			if(yych == '/') goto yy698;
			goto yy702;
		}
	} else {
		if(yych <= '=') {
			if(yych == '<') goto yy702;
			goto yy684;
		} else {
			if(yych <= 'z') goto yy702;
			if(yych <= '}') goto yy684;
			goto yy702;
		}
	}
yy704:
	++YYCURSOR;
	if(YYLIMIT == YYCURSOR) YYFILL(1);
	yych = *YYCURSOR;
yy705:
	if(yych == 0x0A) goto yy690;
	if(yych <= ' ') goto yy704;
	goto yy690;
yy706:
	yyaccept = 1;
	yych = *(YYMARKER = ++YYCURSOR);
	if(yych == 'n') goto yy721;
	goto yy701;
yy707:
	yyaccept = 1;
	yych = *(YYMARKER = ++YYCURSOR);
	if(yych != 'e') goto yy701;
	yyaccept = 1;
	yych = *(YYMARKER = ++YYCURSOR);
	if(yych != 'g') goto yy701;
	yyaccept = 1;
	yych = *(YYMARKER = ++YYCURSOR);
	if(yych != 'i') goto yy701;
	yyaccept = 1;
	yych = *(YYMARKER = ++YYCURSOR);
	if(yych != 'o') goto yy701;
	yyaccept = 1;
	yych = *(YYMARKER = ++YYCURSOR);
	if(yych != 'n') goto yy701;
yy712:
	yyaccept = 1;
	YYMARKER = ++YYCURSOR;
	if(YYLIMIT == YYCURSOR) YYFILL(1);
	yych = *YYCURSOR;
	if(yych <= '/') {
		if(yych <= ' ') {
			if(yych == 0x0A) goto yy717;
			goto yy715;
		} else {
			if(yych == '"') goto yy715;
			if(yych <= '.') goto yy712;
		}
	} else {
		if(yych <= '<') {
			if(yych == ';') goto yy715;
			goto yy712;
		} else {
			if(yych <= '=') goto yy715;
			if(yych <= 'z') goto yy712;
			if(yych <= '}') goto yy715;
			goto yy712;
		}
	}
yy714:
	++YYCURSOR;
	if(YYLIMIT == YYCURSOR) YYFILL(1);
	yych = *YYCURSOR;
	if(yych <= '.') {
		if(yych <= '!') {
			if(yych == 0x0A) goto yy717;
			if(yych >= '!') goto yy719;
		} else {
			if(yych <= '"') goto yy715;
			if(yych != '*') goto yy719;
		}
	} else {
		if(yych <= '<') {
			if(yych <= '/') goto yy715;
			if(yych != ';') goto yy719;
		} else {
			if(yych <= '=') goto yy715;
			if(yych <= 'z') goto yy719;
			if(yych >= '~') goto yy719;
		}
	}
yy715:
	++YYCURSOR;
	if(YYLIMIT == YYCURSOR) YYFILL(1);
	yych = *YYCURSOR;
	if(yych != 0x0A) goto yy715;
yy717:
	++YYCURSOR;
#line 247 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ goto newline; }
#line 4649 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy719:
	yyaccept = 1;
	YYMARKER = ++YYCURSOR;
	if(YYLIMIT == YYCURSOR) YYFILL(1);
	yych = *YYCURSOR;
	if(yych <= '/') {
		if(yych <= ' ') {
			if(yych == 0x0A) goto yy717;
			goto yy715;
		} else {
			if(yych == '"') goto yy715;
			if(yych <= '.') goto yy719;
			goto yy714;
		}
	} else {
		if(yych <= '<') {
			if(yych == ';') goto yy715;
			goto yy719;
		} else {
			if(yych <= '=') goto yy715;
			if(yych <= 'z') goto yy719;
			if(yych <= '}') goto yy715;
			goto yy719;
		}
	}
yy721:
	yyaccept = 1;
	yych = *(YYMARKER = ++YYCURSOR);
	if(yych != 'd') goto yy701;
	yyaccept = 1;
	yych = *(YYMARKER = ++YYCURSOR);
	if(yych != 'r') goto yy701;
	yyaccept = 1;
	yych = *(YYMARKER = ++YYCURSOR);
	if(yych != 'e') goto yy701;
	yyaccept = 1;
	yych = *(YYMARKER = ++YYCURSOR);
	if(yych != 'g') goto yy701;
	yyaccept = 1;
	yych = *(YYMARKER = ++YYCURSOR);
	if(yych != 'i') goto yy701;
	yyaccept = 1;
	yych = *(YYMARKER = ++YYCURSOR);
	if(yych != 'o') goto yy701;
	yyaccept = 1;
	yych = *(YYMARKER = ++YYCURSOR);
	if(yych == 'n') goto yy712;
	goto yy701;
yy728:
	++YYCURSOR;
	if(YYLIMIT == YYCURSOR) YYFILL(1);
	yych = *YYCURSOR;
yy729:
	if(yych != 0x0A) goto yy728;
	++YYCURSOR;
#line 245 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ goto newline; }
#line 4707 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy732:
	++YYCURSOR;
#line 244 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ goto comment; }
#line 4712 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
}
#line 259 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"

	}
	else		// A modified Hexen scanner for DECORATE.
	{
	
#line 4720 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
{
	YYCTYPE yych;
	unsigned int yyaccept = 0;
	if((YYLIMIT - YYCURSOR) < 10) YYFILL(10);
	yych = *YYCURSOR;
	if(yych <= '9') {
		if(yych <= '%') {
			if(yych <= ' ') {
				if(yych == 0x0A) goto yy741;
				goto yy739;
			} else {
				if(yych <= '!') goto yy756;
				if(yych <= '"') goto yy743;
				if(yych <= '#') goto yy738;
				goto yy756;
			}
		} else {
			if(yych <= ',') {
				if(yych <= '&') goto yy751;
				if(yych <= '\'') goto yy757;
				goto yy756;
			} else {
				if(yych <= '-') goto yy745;
				if(yych <= '.') goto yy749;
				if(yych >= '0') goto yy747;
			}
		}
	} else {
		if(yych <= 'Z') {
			if(yych <= '<') {
				if(yych <= ':') goto yy750;
				if(yych <= ';') goto yy756;
				goto yy754;
			} else {
				if(yych <= '=') goto yy752;
				if(yych <= '>') goto yy755;
				if(yych <= '@') goto yy756;
				goto yy757;
			}
		} else {
			if(yych <= 'z') {
				if(yych == '_') goto yy757;
				if(yych <= '`') goto yy756;
				goto yy757;
			} else {
				if(yych == '|') goto yy753;
				if(yych <= '~') goto yy756;
				goto yy757;
			}
		}
	}
	yyaccept = 0;
	yych = *(YYMARKER = ++YYCURSOR);
	if(yych == '*') goto yy823;
	if(yych == '/') goto yy821;
yy737:
#line 282 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ goto normal_token; }
#line 4779 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy738:
	yyaccept = 0;
	yych = *(YYMARKER = ++YYCURSOR);
	if(yych == 'e') goto yy804;
	if(yych == 'r') goto yy805;
	goto yy737;
yy739:
	++YYCURSOR;
	yych = *YYCURSOR;
	goto yy803;
yy740:
#line 269 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ goto std1; }
#line 4793 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy741:
	++YYCURSOR;
#line 270 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ goto newline; }
#line 4798 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy743:
	++YYCURSOR;
#line 271 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ goto string; }
#line 4803 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy745:
	++YYCURSOR;
#line 273 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ goto negative_check; }
#line 4808 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy747:
	++YYCURSOR;
	if((yych = *YYCURSOR) <= '9') {
		if(yych == '.') goto yy785;
		if(yych <= '/') goto yy759;
		goto yy782;
	} else {
		if(yych <= 'E') {
			if(yych <= 'D') goto yy759;
			goto yy784;
		} else {
			if(yych == 'e') goto yy784;
			goto yy759;
		}
	}
yy748:
#line 283 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ goto normal_token; }
#line 4827 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy749:
	yych = *++YYCURSOR;
	if(yych <= '/') goto yy737;
	if(yych <= '9') goto yy772;
	goto yy737;
yy750:
	yych = *++YYCURSOR;
	if(yych == ':') goto yy770;
	goto yy737;
yy751:
	yych = *++YYCURSOR;
	if(yych == '&') goto yy768;
	goto yy737;
yy752:
	yych = *++YYCURSOR;
	if(yych == '=') goto yy766;
	goto yy737;
yy753:
	yych = *++YYCURSOR;
	if(yych == '|') goto yy764;
	goto yy737;
yy754:
	yych = *++YYCURSOR;
	if(yych == '<') goto yy762;
	goto yy737;
yy755:
	yych = *++YYCURSOR;
	if(yych == '>') goto yy760;
	goto yy737;
yy756:
	yych = *++YYCURSOR;
	goto yy737;
yy757:
	yych = *++YYCURSOR;
	goto yy759;
yy758:
	++YYCURSOR;
	if(YYLIMIT == YYCURSOR) YYFILL(1);
	yych = *YYCURSOR;
yy759:
	if(yych <= 'Z') {
		if(yych <= '/') {
			if(yych == '\'') goto yy758;
			goto yy748;
		} else {
			if(yych <= '9') goto yy758;
			if(yych <= '@') goto yy748;
			goto yy758;
		}
	} else {
		if(yych <= '`') {
			if(yych == '_') goto yy758;
			goto yy748;
		} else {
			if(yych <= 'z') goto yy758;
			if(yych <= '~') goto yy748;
			goto yy758;
		}
	}
yy760:
	++YYCURSOR;
#line 281 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ goto normal_token; }
#line 4891 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy762:
	++YYCURSOR;
#line 280 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ goto normal_token; }
#line 4896 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy764:
	++YYCURSOR;
#line 279 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ goto normal_token; }
#line 4901 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy766:
	++YYCURSOR;
#line 278 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ goto normal_token; }
#line 4906 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy768:
	++YYCURSOR;
#line 277 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ goto normal_token; }
#line 4911 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy770:
	++YYCURSOR;
#line 276 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ goto normal_token; }
#line 4916 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy772:
	yyaccept = 1;
	YYMARKER = ++YYCURSOR;
	if((YYLIMIT - YYCURSOR) < 3) YYFILL(3);
	yych = *YYCURSOR;
	if(yych <= 'K') {
		if(yych <= 'D') {
			if(yych <= '/') goto yy774;
			if(yych <= '9') goto yy772;
		} else {
			if(yych <= 'E') goto yy775;
			if(yych <= 'F') goto yy777;
		}
	} else {
		if(yych <= 'e') {
			if(yych <= 'L') goto yy777;
			if(yych >= 'e') goto yy775;
		} else {
			if(yych <= 'f') goto yy777;
			if(yych == 'l') goto yy777;
		}
	}
yy774:
#line 274 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ goto normal_token; }
#line 4942 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy775:
	yych = *++YYCURSOR;
	if(yych <= ',') {
		if(yych == '+') goto yy779;
	} else {
		if(yych <= '-') goto yy779;
		if(yych <= '/') goto yy776;
		if(yych <= '9') goto yy780;
	}
yy776:
	YYCURSOR = YYMARKER;
	if(yyaccept <= 1) {
		if(yyaccept <= 0) {
			goto yy737;
		} else {
			goto yy774;
		}
	} else {
		goto yy748;
	}
yy777:
	++YYCURSOR;
yy778:
#line 275 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ goto normal_token; }
#line 4968 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy779:
	yych = *++YYCURSOR;
	if(yych <= '/') goto yy776;
	if(yych >= ':') goto yy776;
yy780:
	++YYCURSOR;
	if(YYLIMIT == YYCURSOR) YYFILL(1);
	yych = *YYCURSOR;
	if(yych <= 'K') {
		if(yych <= '9') {
			if(yych <= '/') goto yy778;
			goto yy780;
		} else {
			if(yych == 'F') goto yy777;
			goto yy778;
		}
	} else {
		if(yych <= 'f') {
			if(yych <= 'L') goto yy777;
			if(yych <= 'e') goto yy778;
			goto yy777;
		} else {
			if(yych == 'l') goto yy777;
			goto yy778;
		}
	}
yy782:
	++YYCURSOR;
	if((YYLIMIT - YYCURSOR) < 4) YYFILL(4);
	yych = *YYCURSOR;
	if(yych <= 'E') {
		if(yych <= '.') {
			if(yych == '\'') goto yy758;
			if(yych <= '-') goto yy748;
			goto yy785;
		} else {
			if(yych <= '9') {
				if(yych <= '/') goto yy748;
				goto yy782;
			} else {
				if(yych <= '@') goto yy748;
				if(yych <= 'D') goto yy758;
			}
		}
	} else {
		if(yych <= '`') {
			if(yych <= 'Z') goto yy758;
			if(yych == '_') goto yy758;
			goto yy748;
		} else {
			if(yych <= 'e') {
				if(yych <= 'd') goto yy758;
			} else {
				if(yych <= 'z') goto yy758;
				if(yych <= '~') goto yy748;
				goto yy758;
			}
		}
	}
yy784:
	yyaccept = 2;
	yych = *(YYMARKER = ++YYCURSOR);
	if(yych <= ',') {
		if(yych == '+') goto yy796;
		goto yy759;
	} else {
		if(yych <= '-') goto yy796;
		if(yych <= '/') goto yy759;
		if(yych <= '9') goto yy797;
		goto yy759;
	}
yy785:
	yyaccept = 1;
	yych = *(YYMARKER = ++YYCURSOR);
	if(yych == 'E') goto yy788;
	if(yych == 'e') goto yy788;
	goto yy787;
yy786:
	yyaccept = 1;
	YYMARKER = ++YYCURSOR;
	if((YYLIMIT - YYCURSOR) < 3) YYFILL(3);
	yych = *YYCURSOR;
yy787:
	if(yych <= 'K') {
		if(yych <= 'D') {
			if(yych <= '/') goto yy774;
			if(yych <= '9') goto yy786;
			goto yy774;
		} else {
			if(yych <= 'E') goto yy792;
			if(yych <= 'F') goto yy777;
			goto yy774;
		}
	} else {
		if(yych <= 'e') {
			if(yych <= 'L') goto yy777;
			if(yych <= 'd') goto yy774;
			goto yy792;
		} else {
			if(yych <= 'f') goto yy777;
			if(yych == 'l') goto yy777;
			goto yy774;
		}
	}
yy788:
	yych = *++YYCURSOR;
	if(yych <= ',') {
		if(yych != '+') goto yy776;
	} else {
		if(yych <= '-') goto yy789;
		if(yych <= '/') goto yy776;
		if(yych <= '9') goto yy790;
		goto yy776;
	}
yy789:
	yych = *++YYCURSOR;
	if(yych <= '/') goto yy776;
	if(yych >= ':') goto yy776;
yy790:
	++YYCURSOR;
	if(YYLIMIT == YYCURSOR) YYFILL(1);
	yych = *YYCURSOR;
	if(yych <= 'K') {
		if(yych <= '9') {
			if(yych <= '/') goto yy778;
			goto yy790;
		} else {
			if(yych == 'F') goto yy777;
			goto yy778;
		}
	} else {
		if(yych <= 'f') {
			if(yych <= 'L') goto yy777;
			if(yych <= 'e') goto yy778;
			goto yy777;
		} else {
			if(yych == 'l') goto yy777;
			goto yy778;
		}
	}
yy792:
	yych = *++YYCURSOR;
	if(yych <= ',') {
		if(yych != '+') goto yy776;
	} else {
		if(yych <= '-') goto yy793;
		if(yych <= '/') goto yy776;
		if(yych <= '9') goto yy794;
		goto yy776;
	}
yy793:
	yych = *++YYCURSOR;
	if(yych <= '/') goto yy776;
	if(yych >= ':') goto yy776;
yy794:
	++YYCURSOR;
	if(YYLIMIT == YYCURSOR) YYFILL(1);
	yych = *YYCURSOR;
	if(yych <= 'K') {
		if(yych <= '9') {
			if(yych <= '/') goto yy778;
			goto yy794;
		} else {
			if(yych == 'F') goto yy777;
			goto yy778;
		}
	} else {
		if(yych <= 'f') {
			if(yych <= 'L') goto yy777;
			if(yych <= 'e') goto yy778;
			goto yy777;
		} else {
			if(yych == 'l') goto yy777;
			goto yy778;
		}
	}
yy796:
	yych = *++YYCURSOR;
	if(yych <= '/') goto yy776;
	if(yych <= '9') goto yy800;
	goto yy776;
yy797:
	++YYCURSOR;
	if((YYLIMIT - YYCURSOR) < 2) YYFILL(2);
	yych = *YYCURSOR;
	if(yych <= 'Z') {
		if(yych <= '@') {
			if(yych <= '\'') {
				if(yych <= '&') goto yy778;
				goto yy758;
			} else {
				if(yych <= '/') goto yy778;
				if(yych <= '9') goto yy797;
				goto yy778;
			}
		} else {
			if(yych <= 'F') {
				if(yych <= 'E') goto yy758;
			} else {
				if(yych != 'L') goto yy758;
			}
		}
	} else {
		if(yych <= 'f') {
			if(yych <= '_') {
				if(yych <= '^') goto yy778;
				goto yy758;
			} else {
				if(yych <= '`') goto yy778;
				if(yych <= 'e') goto yy758;
			}
		} else {
			if(yych <= 'l') {
				if(yych <= 'k') goto yy758;
			} else {
				if(yych <= 'z') goto yy758;
				if(yych <= '~') goto yy778;
				goto yy758;
			}
		}
	}
	yych = *++YYCURSOR;
	if(yych <= 'Z') {
		if(yych <= '/') {
			if(yych == '\'') goto yy758;
			goto yy778;
		} else {
			if(yych <= '9') goto yy758;
			if(yych <= '@') goto yy778;
			goto yy758;
		}
	} else {
		if(yych <= '`') {
			if(yych == '_') goto yy758;
			goto yy778;
		} else {
			if(yych <= 'z') goto yy758;
			if(yych <= '~') goto yy778;
			goto yy758;
		}
	}
yy800:
	++YYCURSOR;
	if(YYLIMIT == YYCURSOR) YYFILL(1);
	yych = *YYCURSOR;
	if(yych <= 'K') {
		if(yych <= '9') {
			if(yych <= '/') goto yy778;
			goto yy800;
		} else {
			if(yych == 'F') goto yy777;
			goto yy778;
		}
	} else {
		if(yych <= 'f') {
			if(yych <= 'L') goto yy777;
			if(yych <= 'e') goto yy778;
			goto yy777;
		} else {
			if(yych == 'l') goto yy777;
			goto yy778;
		}
	}
yy802:
	++YYCURSOR;
	if(YYLIMIT == YYCURSOR) YYFILL(1);
	yych = *YYCURSOR;
yy803:
	if(yych == 0x0A) goto yy740;
	if(yych <= ' ') goto yy802;
	goto yy740;
yy804:
	yych = *++YYCURSOR;
	if(yych == 'n') goto yy814;
	goto yy776;
yy805:
	yych = *++YYCURSOR;
	if(yych != 'e') goto yy776;
	yych = *++YYCURSOR;
	if(yych != 'g') goto yy776;
	yych = *++YYCURSOR;
	if(yych != 'i') goto yy776;
	yych = *++YYCURSOR;
	if(yych != 'o') goto yy776;
	yych = *++YYCURSOR;
	if(yych != 'n') goto yy776;
yy810:
	++YYCURSOR;
	if(YYLIMIT == YYCURSOR) YYFILL(1);
	yych = *YYCURSOR;
	if(yych != 0x0A) goto yy810;
	++YYCURSOR;
#line 267 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ goto newline; }
#line 5263 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy814:
	yych = *++YYCURSOR;
	if(yych != 'd') goto yy776;
	yych = *++YYCURSOR;
	if(yych != 'r') goto yy776;
	yych = *++YYCURSOR;
	if(yych != 'e') goto yy776;
	yych = *++YYCURSOR;
	if(yych != 'g') goto yy776;
	yych = *++YYCURSOR;
	if(yych != 'i') goto yy776;
	yych = *++YYCURSOR;
	if(yych != 'o') goto yy776;
	yych = *++YYCURSOR;
	if(yych == 'n') goto yy810;
	goto yy776;
yy821:
	++YYCURSOR;
	if(YYLIMIT == YYCURSOR) YYFILL(1);
	yych = *YYCURSOR;
	if(yych == 0x0A) goto yy825;
	goto yy821;
yy823:
	++YYCURSOR;
#line 264 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ goto comment; }
#line 5290 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy825:
	++YYCURSOR;
#line 265 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ goto newline; }
#line 5295 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
}
#line 286 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"

	}

negative_check:
	// re2c doesn't have enough state to handle '-' as the start of a negative number
	// and as its own token, so help it out a little.
	TokenType = '-';
	if (YYCURSOR >= YYLIMIT)
	{
		goto normal_token;
	}
	if (*YYCURSOR >= '0' && *YYCURSOR <= '9')
	{
		goto std2;
	}
	if (*YYCURSOR != '.' || YYCURSOR+1 >= YYLIMIT)
	{
		goto normal_token;
	}
	if (*(YYCURSOR+1) >= '0' && *YYCURSOR <= '9')
	{
		goto std2;
	}
	goto normal_token;

comment:

#line 5325 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
{
	YYCTYPE yych;
	if((YYLIMIT - YYCURSOR) < 2) YYFILL(2);
	yych = *YYCURSOR;
	if(yych == 0x0A) goto yy831;
	if(yych != '*') goto yy833;
	++YYCURSOR;
	if((yych = *YYCURSOR) == '/') goto yy834;
yy830:
#line 335 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{ goto comment; }
#line 5337 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy831:
	++YYCURSOR;
#line 324 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{
			if (YYCURSOR >= YYLIMIT)
			{
				ScriptPtr = ScriptEndPtr;
				return_val = false;
				goto end;
			}
			Line++;
			Crossed = true;
			goto comment;
		}
#line 5352 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
yy833:
	yych = *++YYCURSOR;
	goto yy830;
yy834:
	++YYCURSOR;
#line 314 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"
	{
			if (YYCURSOR >= YYLIMIT)
			{
				ScriptPtr = ScriptEndPtr;
				return_val = false;
				goto end;
			}
			goto std1;
		}
#line 5368 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.h"
}
#line 336 "/Users/mwydmuch/Workspace/ViZDoom2/src/vizdoom/src/sc_man_scanner.re"


newline:
	if (YYCURSOR >= YYLIMIT)
	{
		ScriptPtr = ScriptEndPtr;
		return_val = false;
		goto end;
	}
	Line++;
	Crossed = true;
	goto std1;

normal_token:
	ScriptPtr = (YYCURSOR >= YYLIMIT) ? ScriptEndPtr : cursor;
	StringLen = int(ScriptPtr - tok);
	if (tokens && (TokenType == TK_StringConst || TokenType == TK_NameConst))
	{
		StringLen -= 2;
		if (StringLen >= MAX_STRING_SIZE)
		{
			BigStringBuffer = FString(tok+1, StringLen);
		}
		else
		{
			memcpy (StringBuffer, tok+1, StringLen);
		}
	}
	else
	{
		if (StringLen >= MAX_STRING_SIZE)
		{
			BigStringBuffer = FString(tok, StringLen);
		}
		else
		{
			memcpy (StringBuffer, tok, StringLen);
		}
	}
	if (StringLen < MAX_STRING_SIZE)
	{
		String = StringBuffer;
		StringBuffer[StringLen] = '\0';
	}
	else
	{
		String = BigStringBuffer.LockBuffer();
	}
	return_val = true;
	goto end;

string:
	if (YYLIMIT != ScriptEndPtr)
	{
		ScriptPtr = ScriptEndPtr;
		return_val = false;
		goto end;
	}
	ScriptPtr = cursor;
	BigStringBuffer = "";
	for (StringLen = 0; cursor < YYLIMIT; ++cursor)
	{
		if (Escape && *cursor == '\\' && *(cursor + 1) == '"')
		{
			cursor++;
		}
		else if (*cursor == '\r' && *(cursor + 1) == '\n')
		{
			cursor++;	// convert CR-LF to simply LF
		}
		else if (*cursor == '"')
		{
			break;
		}
		if (*cursor == '\n')
		{
			if (CMode)
			{
				if (!Escape || StringLen == 0 || String[StringLen - 1] != '\\')
				{
					ScriptError ("Unterminated string constant");
				}
				else
				{
					StringLen--;		// overwrite the \ character with \n
				}
			}
			Line++;
			Crossed = true;
		}
		if (StringLen == MAX_STRING_SIZE)
		{
			BigStringBuffer.AppendCStrPart(StringBuffer, StringLen);
			StringLen = 0;
		}
		StringBuffer[StringLen++] = *cursor;
	}
	if (BigStringBuffer.IsNotEmpty() || StringLen == MAX_STRING_SIZE)
	{
		BigStringBuffer.AppendCStrPart(StringBuffer, StringLen);
		String = BigStringBuffer.LockBuffer();
		StringLen = int(BigStringBuffer.Len());
	}
	else
	{
		String = StringBuffer;
		StringBuffer[StringLen] = '\0';
	}
	ScriptPtr = cursor + 1;
	return_val = true;
end:
